@@ -1,56 +1,62 @@
 #!/usr/bin/env python
 
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
 """
 event.py:
 """
-from __future__ import print_function
-from __future__ import absolute_import
-from builtins import range
-from builtins import object
+
 import sys
 import weakref
 import threading
 import time
-import collections
+from collections.abc import Sequence
 import taurus.core
+from .object import Object
 
 
-__all__ = ["BoundMethodWeakref", "CallableRef", "EventGenerator",
-           "ConfigEventGenerator", "ListEventGenerator", "EventListener",
-           "AttributeEventWait", "AttributeEventIterator"]
+__all__ = [
+    "BoundMethodWeakref",
+    "CallableRef",
+    "EventGenerator",
+    "ConfigEventGenerator",
+    "ListEventGenerator",
+    "EventListener",
+    "AttributeEventWait",
+    "AttributeEventIterator",
+]
 
 __docformat__ = "restructuredtext"
 
 
 class BoundMethodWeakref(object):
     """This class represents a weak reference to a method of an object since
-    weak references to methods don't work by themselves"""
+    weak references to methods don't work by themselves
+    """
 
     def __init__(self, bound_method, del_cb=None):
-        cb = (del_cb and self._deleted)
+        cb = del_cb and self._deleted
         self.func_ref = weakref.ref(bound_method.__func__, cb)
         self.obj_ref = weakref.ref(bound_method.__self__, cb)
         if cb:
@@ -74,18 +80,12 @@ class BoundMethodWeakref(object):
     def __hash__(self):
         return id(self)
 
-    def __cmp__(self, other):
-        if other.__class__ == self.__class__:
-            from past.builtins import cmp
-            ret = cmp((self.func_ref, self.obj_ref),
-                      (other.func_ref, other.obj_ref))
-            return ret
-        return 1
-
     def __eq__(self, other):
-        if hasattr(other, 'func_ref') and hasattr(other, 'obj_ref'):
-            return ((self.func_ref, self.obj_ref)
-                    == (other.func_ref, other.obj_ref))
+        if hasattr(other, "func_ref") and hasattr(other, "obj_ref"):
+            return (self.func_ref, self.obj_ref) == (
+                other.func_ref,
+                other.obj_ref,
+            )
         return False
 
     def __ne__(self, other):
@@ -93,7 +93,7 @@ class BoundMethodWeakref(object):
 
     def __repr__(self):
         obj, func = self.obj_ref(), self.func_ref()
-        return 'BoundMethodWeakRef of %s.%s' % (obj, func)
+        return "BoundMethodWeakRef of %s.%s" % (obj, func)
 
 
 def CallableRef(object, del_cb=None):
@@ -104,13 +104,13 @@ def CallableRef(object, del_cb=None):
     :type object: callable object
     :param del_cb: calback function. Default is None meaning to callback.
     :type del_cb: callable object or None
-
     :return: a weak reference for the given callable
-    :rtype: BoundMethodWeakref or weakref.ref"""
+    :rtype: taurus.core.util.BoundMethodWeakref or weakref.ref
+    """
     im_self = None
-    if hasattr(object, '__self__'):
+    if hasattr(object, "__self__"):
         im_self = object.__self__
-    elif hasattr(object, 'im_self'):
+    elif hasattr(object, "im_self"):
         im_self = object.im_self
 
     if im_self is not None:
@@ -123,16 +123,15 @@ def CallableRef(object, del_cb=None):
 # Related to "Keeping references to event callbacks after unsubscribe_event"
 # PyTango #185 issue.
 class _BoundMethodWeakrefWithCall(BoundMethodWeakref):
-
     def __init__(self, bound_method, del_cb=None):
-        """ Reimplementation of __init__ method"""
-        super(_BoundMethodWeakrefWithCall, self).__init__(bound_method,
-                                                          del_cb=del_cb)
+        """Reimplementation of __init__ method"""
+        super(_BoundMethodWeakrefWithCall, self).__init__(
+            bound_method, del_cb=del_cb
+        )
         self.__name__ = self.func_ref().__name__
 
     def __call__(self, *args, **kwargs):
-        """ Retrieve references and call callback with arguments
-        """
+        """Retrieve references and call callback with arguments"""
         obj = self.obj_ref()
         if obj is not None:
             func = self.func_ref()
@@ -141,7 +140,7 @@ class _BoundMethodWeakrefWithCall(BoundMethodWeakref):
 
 
 class EventStack(object):
-    "internal usage event stack"
+    """internal usage event stack"""
 
     def __init__(self, history=True):
         self.unread_stack = []
@@ -175,9 +174,6 @@ class EventStack(object):
         return read
 
 
-from .object import Object
-
-
 class EventGenerator(Object):
     """Base class capable of firing events"""
 
@@ -191,7 +187,8 @@ class EventGenerator(Object):
         :param events_active: generate events (default is True)
         :type  events_active: bool
         :return: a new EventGenerator
-        :rtype: EventGenerator"""
+        :rtype: EventGenerator
+        """
         self.call__init__(Object)
         self.event_name = name
         self.cb_list = []
@@ -226,16 +223,19 @@ class EventGenerator(Object):
         :type data: boolean
         """
         if not self.events_active:
-            raise RuntimeError('%s does not have '
-                                 'events/polling active' % self.event_name)
+            raise RuntimeError(
+                "%s does not have " "events/polling active" % self.event_name
+            )
 
         cb_ref = CallableRef(cb, self.unsubscribeDeletedEvent)
 
         try:
             self.lock()
             if (cb_ref, data) in self.cb_list:
-                raise RuntimeError('Callback %s(%s) already reg. on %s' %
-                                     (cb, data, self.event_name))
+                raise RuntimeError(
+                    "Callback %s(%s) already reg. on %s"
+                    % (cb, data, self.event_name)
+                )
             self.cb_list.append((cb_ref, data))
             if with_first_event:
                 cb(data, self.first_event_val)
@@ -255,22 +255,26 @@ class EventGenerator(Object):
             self.unlock()
 
     def unsubscribeEvent(self, cb, data=None):
-        """Unsubscribes the given callback from the event. If the callback is not
-        a listener for this event a debug message is generated an nothing happens.
+        """Unsubscribes the given callback from the event. If the callback is
+        not a listener for this event a debug message is generated an nothing
+        happens.
 
         :param cb: a callable object
         :type  cb: callable
         :param data: extra data to send each time an event is triggered on the
-                     given callback. Default is None
-        :type  data: object"""
+            given callback. Default is None
+        :type  data: object
+        """
         cb_ref = CallableRef(cb)
         try:
             self.lock()
             if (cb_ref, data) in self.cb_list:
                 self.cb_list.remove((cb_ref, data))
             else:
-                self.debug("Trying to unsubscribe: %s is not a listener of %s" % (
-                    str(cb_ref), self.event_name))
+                self.debug(
+                    "Trying to unsubscribe: %s is not a listener of %s"
+                    % (str(cb_ref), self.event_name)
+                )
         finally:
             self.unlock()
 
@@ -280,10 +284,11 @@ class EventGenerator(Object):
         :param cb: a callable object
         :type  cb: callable
         :param data: extra data to send each time an event is triggered on the
-                     given callback. Default is None
+            given callback. Default is None
         :type  data: object
         :return: True if callback is registered or False otherwise
-        :rtype: bool"""
+        :rtype: bool
+        """
         cb_ref = CallableRef(cb, self.unsubscribeDeletedEvent)
         return (cb_ref, data) in self.cb_list
 
@@ -291,19 +296,23 @@ class EventGenerator(Object):
         """(De)activates events on this event generator.
 
         :param events_active: activate/deactivate events
-        :type  events_active: bool"""
+        :type  events_active: bool
+        """
         self.events_active = events_active
 
     def getEventsActive(self):
         """Determines is events are active
         :return: True if events are active or False otherwise
-        :rtype: bool"""
+        :rtype: bool
+        """
         return self.events_active
 
     def fireEvent(self, val, event_val=None):
         """Fires an event.
+
         :param val: event value
-        :type  val: object"""
+        :type  val: object
+        """
         try:
             self.lock()
             self.last_val = val
@@ -320,8 +329,9 @@ class EventGenerator(Object):
         finally:
             self.unlock()
 
-    def waitEvent(self, val=None, equal=True, any=False, timeout=None,
-                  stack=None):
+    def waitEvent(
+        self, val=None, equal=True, any=False, timeout=None, stack=None
+    ):
         """Waits for an event to occur
 
         :param val: event value
@@ -329,17 +339,19 @@ class EventGenerator(Object):
         :param equal: check for equality. Default is True
         :type  equal: bool
         :param any: if True unblock after first event, not matter what value it
-                    has. Default is False.
+            has. Default is False.
         :type  any: bool
         :param timeout: maximum time to wait (seconds). Default is None meaning
-               wait forever.
+            wait forever.
         :type  timeout: float
         :param stack: For internal usage only.
         :return: the value of the event that unblocked the wait
-        :rtype: object"""
+        :rtype: object
+        """
         if not self.events_active:
-            raise RuntimeError('%s does not have '
-                                 'events/polling active' % self.event_name)
+            raise RuntimeError(
+                "%s does not have " "events/polling active" % self.event_name
+            )
         try:
             self.lock()
             t0 = time.time()
@@ -353,10 +365,11 @@ class EventGenerator(Object):
                 if any:
                     block = not avail
                 else:
-                    block = ((equal and (val != curr_val)) or
-                             (not equal and (val == curr_val)))
+                    block = (equal and (val != curr_val)) or (
+                        not equal and (val == curr_val)
+                    )
                 if timeout:
-                    timeout_expired = (time.time() - t0 > timeout)
+                    timeout_expired = time.time() - t0 > timeout
                 if not block or timeout_expired:
                     break
                 self.wait_list.append(stack)
@@ -372,7 +385,8 @@ class EventGenerator(Object):
         """Read the last event
 
         :return: the last event value
-        :rtype: object"""
+        :rtype: object
+        """
         return self.last_val
 
 
@@ -381,7 +395,8 @@ class EventListener(object):
 
     Note: Since this class stores for each event value the last timestamp when
     it occured, it should only be used for events for which the event value
-    domain (possible values) is limited and well known (ex: an enum)"""
+    domain (possible values) is limited and well known (ex: an enum)
+    """
 
     def __init__(self):
         self.last_val = None
@@ -415,7 +430,8 @@ class EventListener(object):
         this function when you have the lock acquired on this object.
 
         :param v: event value
-        :type  v: object"""
+        :type  v: object
+        """
         try:
             t = time.time()
             self.lock()
@@ -426,9 +442,9 @@ class EventListener(object):
             self.unlock()
 
     def waitEvent(self, val, after=0, equal=True):
-        """Wait for an event with the given value. You MUST protect this function
-        with this object's lock before calling this method and always unlock it
-        afterward, of course::
+        """Wait for an event with the given value. You MUST protect this
+        function with this object's lock before calling this method and always
+        unlock it afterward, of course::
 
             from taurus.core.util.event import EventListener
 
@@ -448,10 +464,10 @@ class EventListener(object):
         :param val: value to compare
         :type  val: object
         :param after: timestamp. wait for events comming after the given time.
-                      default value is 0 meaning any event after Jan 1, 1970
+            default value is 0 meaning any event after Jan 1, 1970
         :type  after: float
         :param equal: compare for equality. equal=True means an event with the
-                      given value, equal=False means any event which as a different value
+            given value, equal=False means any event which as a different value
         :type  equal: bool
         """
         s = self.event_set
@@ -490,7 +506,8 @@ class ListEventGenerator(EventGenerator):
         this function when you have the lock acquired on this object.
 
         :param val: event value
-        :type  val: object"""
+        :type  val: object
+        """
         # if attribute is not alive and last time was also not alive then
         # skip the event propagation
         if val is None:
@@ -512,8 +529,9 @@ class ListEventGenerator(EventGenerator):
 
 
 class AttributeEventWait(object):
-    """Class designed to connect to a :class:`taurus.core.taurusattribute.TaurusAttribute` and
-    fire events or wait for a certain event."""
+    """Class designed to connect to a
+    :class:`taurus.core.taurusattribute.TaurusAttribute` and fire events or
+    wait for a certain event."""
 
     def __init__(self, attr=None):
         self._last_val = None
@@ -525,8 +543,10 @@ class AttributeEventWait(object):
 
     def connect(self, attr):
         """Connect to the given attribute
+
         :param attr: the attribute to connect to
-        :type  attr: taurus.core.taurusattribute.TaurusAttribute"""
+        :type  attr: taurus.core.taurusattribute.TaurusAttribute
+        """
         needAdd = True
         if self._attr is not None:
             if attr == self._attr:
@@ -563,8 +583,10 @@ class AttributeEventWait(object):
                 name = th.name
             else:
                 name = "<unknown>"
-            print("WARNING: Thread %s trying to unlock condition previously " \
-                  "locked by thread %s" % (curr_th.name, name))
+            print(
+                "WARNING: Thread %s trying to unlock condition previously "
+                "locked by thread %s" % (curr_th.name, name)
+            )
 
     def clearEventSet(self):
         "Clears the internal event buffer"
@@ -574,7 +596,8 @@ class AttributeEventWait(object):
     def eventReceived(self, s, t, v):
         """Event listener method for the underlying attribute. Do not call this
         method. It will be called internally when the attribute generates
-        an event."""
+        an event.
+        """
         if t == taurus.core.taurusbasetypes.TaurusEventType.Config:
             return
         elif t == taurus.core.taurusbasetypes.TaurusEventType.Error:
@@ -588,7 +611,8 @@ class AttributeEventWait(object):
         this function when you have the lock acquired on this object.
 
         :param v: event value
-        :type  v: object"""
+        :type  v: object
+        """
         t = time.time()
         self.lock()
         try:
@@ -603,49 +627,81 @@ class AttributeEventWait(object):
         been received or the last event was an error event
 
         :return: the last event value to be recorded
-        :rtype: object"""
+        :rtype: object
+        """
         return self._last_val
 
     def getRecordedEvents(self):
-        """Returns a reference to the internal dictionary used to store the internal
-        events. Modify the return dictionary at your own risk!
+        """Returns a reference to the internal dictionary used to store the
+        internal events. Modify the return dictionary at your own risk!
 
         :return: reference to the internal event dictionary
-        :rtype: dict"""
+        :rtype: dict
+        """
         return self._event_set
 
     def getRecordedEvent(self, v):
-        """Returns the the recorded local timestamp for the event with the given
-        value or None if no event with the given value has been recorded.
+        """Returns the the recorded local timestamp for the event with the
+        given value or None if no event with the given value has been recorded.
 
         :param v: event value
         :type  v: object
-        :return: local timestamp for the event or None if no event has been recorded
-        :rtype: float"""
+        :return: local timestamp for the event or None if no event has been
+            recorded
+        :rtype: float
+        """
         return self._event_set.get(v)
 
-    def waitEvent(self, val, after=0, equal=True, timeout=None, retries=-1,
-                  any=False):
+    def _isEventRecorded(self, values, after, equal, ignore_values):
+        s = self._event_set
+        if ignore_values:
+            for v, t in s.items():
+                if t >= after:
+                    return True
+            return False
+        for value in values:
+            if equal:
+                t = s.get(value)
+                if t is not None and t >= after:
+                    return True
+            else:
+                for v, t in s.items():
+                    if v == value:
+                        continue
+                    if t >= after:
+                        return True
+        return False
+
+    def waitEvent(
+        self, val, after=0, equal=True, timeout=None, retries=-1, any=False
+    ):
         """Wait for an event with the given value.
 
         :param val: value to compare
         :type  val: object
         :param after: timestamp. wait for events comming after the given time.
-                      default value is 0 meaning any event after Jan 1, 1970
+            default value is 0 meaning any event after Jan 1, 1970
         :type  after: float
         :param equal: compare for equality. equal=True means an event with the
-                      given value, equal=False means any event which as a different value
+            given value, equal=False means any event which as a different value
         :type  equal: bool
         :param timeout: maximum time to wait (seconds). Default is None meaning
-               wait forever.
+            wait forever.
         :type  timeout: float
         :param retries: number of maximum retries of max timeout to attempts.
-                        Default is -1 meaning infinite number of retries.
-                        0 means no wait. Positive number is obvious.
+            Default is -1 meaning infinite number of retries. 0 means no wait.
+            Positive number is obvious.
         :param any: if any is True ignore 'val' parameter and accept any event.
-                    If False (default),check with given 'val' parameter
+            If False (default),check with given 'val' parameter
         :type  any: bool
         """
+        from taurus.core.util.log import deprecated
+
+        deprecated(
+            dep="`AttributeEventWait.waitEvent()`",
+            alt="`AttributeEventWait.waitForEvent()`",
+            rel="4.9.0.dev",
+        )
         if retries == 0:
             return
         if timeout is None:
@@ -678,11 +734,77 @@ class AttributeEventWait(object):
                 retries -= 1
         except Exception as e:
             sys.stderr.write(
-                "AttributeEventWait: Caught exception while waiting: %s\n" % str(e))
+                "AttributeEventWait: Caught exception while waiting: %s\n"
+                % str(e)
+            )
             raise e
         finally:
             self.unlock()
 
+    def waitForEvent(
+        self,
+        values,
+        after=0,
+        equal=True,
+        timeout=None,
+        reactivity=None,
+        ignore_values=False,
+    ):
+        """Wait for an event that matches some given conditions.
+
+        :param values: the event value should match one of this
+        :type  values: seq<object>
+        :param after: timestamp. wait for events comming after the given time.
+            default value is 0 meaning any event after Jan 1, 1970
+        :type  after: float
+        :param equal: compare for equality. equal=True means an event with the
+            given value, equal=False means any event which as a different value
+        :type  equal: bool
+        :param timeout: maximum time to wait (seconds). Default is None meaning
+            wait forever.
+        :type  timeout: float
+        :param reactivity: setting reactivity (seconds) waranties reactions to
+            aborts comming from other threads in at most the reactivity time.
+            Default is None meaning no reactivity within timeout.
+        :param ignore_values: if any is True ignore 'values' parameter and
+            accept any event. If False (default),check with given 'values'
+            parameter
+        :type  ignore_values: bool
+        :return: The return value is `True` unless a given timeout expired, in
+            which case it is `False`.
+        :rtype: bool
+        """
+
+        if timeout is not None and reactivity is not None:
+            assert timeout > reactivity
+        if timeout is None:
+            timeout = float("inf")
+        if reactivity is None:
+            reactivity = timeout
+        if after is None:
+            after = 0
+        start_time = time.time()
+        result = False
+        self.lock()
+        try:
+            while True:
+                result = self._isEventRecorded(
+                    values, after, equal, ignore_values
+                )
+                if result:
+                    break
+                elapsed_time = time.time() - start_time
+                if elapsed_time > timeout:
+                    break
+                left_time = timeout - elapsed_time
+                wait_timeout = min(reactivity, left_time)
+                if wait_timeout == float("inf"):
+                    wait_timeout = None
+                self._cond.wait(wait_timeout)
+        finally:
+            self.unlock()
+        return result
+
 
 class AttributeEventIterator(object):
     """Internal class. For test purposes"""
@@ -694,7 +816,7 @@ class AttributeEventIterator(object):
             self.connect(attrs)
 
     def connect(self, attrs):
-        if not isinstance(attrs, collections.Sequence):
+        if not isinstance(attrs, Sequence):
             attrs = (attrs,)
         self.disconnect()
         self._attrs = attrs
@@ -717,16 +839,23 @@ class AttributeEventIterator(object):
             lock = getattr(self._cond, "_Condition__lock")
             th = getattr(lock, "_RLock__owner")
             curr_th = threading.current_thread()
-            print(("WARNING: Thread %s trying to unlock condition previously "
-                   + "locked by thread %s") % (curr_th.name, th.name))
+            print(
+                (
+                    "WARNING: Thread %s trying to unlock condition previously "
+                    + "locked by thread %s"
+                )
+                % (curr_th.name, th.name)
+            )
 
     def eventReceived(self, s, t, v):
-        if t not in (taurus.core.taurusbasetypes.TaurusEventType.Change, taurus.core.taurusbasetypes.TaurusEventType.Periodic):
+        if t not in (
+            taurus.core.taurusbasetypes.TaurusEventType.Change,
+            taurus.core.taurusbasetypes.TaurusEventType.Periodic,
+        ):
             return
         self.fireEvent(s, v.rvalue)
 
     def fireEvent(self, s, v):
-        t = time.time()
         self.lock()
         try:
             self._data = s, v
