@@ -1,37 +1,34 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
-"""This module provides a taurus QPushButton based widgets"""
-from __future__ import print_function
+"""This module provides a taurus QPushButton based widgets
+"""
+import importlib
 
-from builtins import map
-from builtins import str
-from future.utils import string_types
-
-from taurus.external.qt import Qt
+from taurus.external.qt import Qt, compat
 from taurus.core.taurusbasetypes import LockStatus, TaurusLockInfo
 from taurus.core.taurusdevice import TaurusDevice
 from taurus.qt.qtgui.base import TaurusBaseWidget
@@ -39,9 +36,7 @@ from taurus.core.util import eventfilters
 from taurus.qt.qtgui.dialog import ProtectTaurusMessageBox
 
 
-__all__ = ["TaurusLauncherButton", "TaurusCommandButton", "TaurusLockButton"]
-
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
 
 class _ButtonDialog(Qt.QDialog):
@@ -50,8 +45,8 @@ class _ButtonDialog(Qt.QDialog):
 
     def __init__(self, parent=None):
         Qt.QDialog.__init__(self, parent, Qt.Qt.WindowTitleHint)
-        l = Qt.QVBoxLayout()
-        self.setLayout(l)
+        lyt = Qt.QVBoxLayout()
+        self.setLayout(lyt)
         self.previousWidgetConfig = None
 
     def setWidget(self, widget):
@@ -59,7 +54,7 @@ class _ButtonDialog(Qt.QDialog):
         if oldWidget is not None:
             try:
                 self._widget.setModel(None)
-            except:
+            except Exception:
                 pass
             oldWidget.hide()
             oldWidget.setParent(None)
@@ -75,14 +70,14 @@ class _ButtonDialog(Qt.QDialog):
         if self.deleteWidgetOnClose:
             try:
                 self.previousWidgetConfig = self.widget().createConfig()
-            except:
+            except Exception:
                 self.previousWidgetConfig = None
             self.setWidget(None)
         Qt.QDialog.closeEvent(self, event)
 
 
 class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
-    '''This class provides a button that launches a modeless dialog containing
+    """This class provides a button that launches a modeless dialog containing
     a specified Taurus widget which gets the same model as the button.
     The button does not use the model directly. Instead it passes it to the
     associated widget.
@@ -90,32 +85,44 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
     Code examples::
 
         # a button that launches a TaurusAttrForm when clicked
-        button =  TaurusLauncherButton(widget = TaurusAttrForm())
-        button.setModel('a/b/c') #a device name, which will be set at the TaurusAttrForm when clicking
+        b = TaurusLauncherButton(widget = TaurusAttrForm())
+        # set dev name, which will be set at the TaurusAttrForm when clicking
+        b.setModel("a/b/c")
 
-        # a button that launches a taurusLabel (whose model is an attribute: 'a/b/c/attrname')
-        button =  TaurusLauncherButton(widget = TaurusLabel())
-        button.setModel('a/b/c/attrname') # attr name, which will be set at the TaurusLabel when clicking
+        # a button that launches a taurusLabel
+        b = TaurusLauncherButton(widget="taurus.qt.qtgui.display:TaurusLabel")
+        b.setModel("a/b/c/d")
 
-    '''
+        # a button that launches a TaurusPlot
+        b = TaurusLauncherButton(widget="taurus_pyqtgraph:TaurusPlot")
+        b.setModel("eval:rand(50)")
+    """
 
-    _widgetClassName = ''
+    _widgetClassName = ""
     _args = []
     _kwargs = {}
     _deleteWidgetOnClose = True
     _icon = None
     _text = None
 
-    def __init__(self, parent=None, designMode=False, widget=None, icon=None, text=None):
-        '''Constructor
+    def __init__(
+        self, parent=None, designMode=False, widget=None, icon=None, text=None
+    ):
+        """Constructor
 
-        :param parent: (Qt.QWidget or None) parent of this widget
-        :param designMode: (bool) flag for Qt designer
-        :param widget: (Qt.QWidget) a QWidget that will be shown when clicking
-                       in the button
-        :param icon: (Qt.QIcon) icon for the button
-        :param text: (str) the button text (if None passed, the widget's class name
-                     is used) '''
+        :param parent: parent of this widget
+        :type parent: Qt.QWidget or None
+        :param designMode: flag for Qt designer
+        :type designMode: bool
+        :param widget: a QWidget (or its "module:class" specification) that
+            will be shown when clicking in the button
+        :type widget: Qt.QWidget or str
+        :param icon: icon for the button
+        :type icon: Qt.QIcon
+        :param text: the button text (if None passed, the widget's class name
+            is used)
+        :type text: str
+        """
 
         name = self.__class__.__name__
         self.call__init__wo_kw(Qt.QPushButton, parent)
@@ -141,12 +148,13 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
         self._updateText()
 
     def getModelClass(self):
-        '''see :meth:`TaurusBaseComponent.getModelClass`. Note that in the case of
-        :class:`TaurusLauncherButton`, the class is completely dependent on the
-        widget's class'''
+        """see :meth:`TaurusBaseComponent.getModelClass`. Note that in the case
+        of :class:`TaurusLauncherButton`, the class is completely dependent on
+        the widget's class
+        """
         try:
             return self.widget().getModelClass()
-        except:
+        except Exception:
             # return None  #@TODO: Uncommenting this avoids the exception when
             # TaurusBaseWidget.getModelClass chokes with relative classes. But
             # the thing should be solved at TaurusBaseWidget.getModelClass
@@ -154,7 +162,7 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
             return TaurusBaseWidget.getModelClass(self)
 
     def setText(self, text):
-        '''Sets the text of the button. see :meth:`Qt.QPushButton.setText`'''
+        """Sets the text of the button. see :meth:`Qt.QPushButton.setText`"""
         self._text = text
         Qt.QPushButton.setText(self, text)
 
@@ -173,8 +181,24 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
         self.setWidgetClassName(self.__class__._widgetClassName)
 
     def createWidget(self):
-        from taurus.qt.qtgui.util import TaurusWidgetFactory
-        klass = TaurusWidgetFactory().getWidgetClass(self._widgetClassName)
+        if ":" in self._widgetClassName:
+            # assuming pkg_resources-style spec:  modname:object[.attr]
+            mod_name, class_name = self._widgetClassName.split(":")
+            klass = getattr(importlib.import_module(mod_name), class_name)
+        else:
+            # using TaurusWidgetFactory, deprecated
+            from taurus.qt.qtgui.util import TaurusWidgetFactory
+
+            _qt_widgets = TaurusWidgetFactory()._qt_widgets
+            _modname, klass = _qt_widgets[self._widgetClassName]
+            self.deprecated(
+                dep="specifying the classname ('{}') without module".format(
+                    self._widgetClassName
+                ),
+                alt="'{}:{}'".format(_modname, self._widgetClassName),
+                rel="5.0.0",
+            )
+
         widget = klass(*self._args, **self._kwargs)
         self.setWidget(widget)
         if self._dialog.previousWidgetConfig is not None:
@@ -182,41 +206,46 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
                 widget.applyConfig(self._dialog.previousWidgetConfig)
             except Exception as e:
                 self.warning(
-                    'Cannot apply previous configuration to widget. Reason: %s', repr(e))
+                    "Cannot apply previous configuration to widget. "
+                    + "Reason: %s",
+                    repr(e),
+                )
 
     def widget(self):
         return self._dialog.widget()
 
     def setWidget(self, widget):
-        '''sets the widget that will be shown when clicking the button
+        """sets the widget that will be shown when clicking the button
 
-        :param widget: (Qt.QWidget)
-        '''
+        :param widget:
+        :type widget: Qt.QWidget
+        """
         self._dialog.setWidget(widget)
         self._updateText()
 
     def displayValue(self, v):
-        '''see :meth:`TaurusBaseComponent.displayValue`'''
+        """see :meth:`TaurusBaseComponent.displayValue`"""
         if self._text is not None:
             return self._text  # make sure the text is not changed once set
         TaurusBaseWidget.displayValue(self, v)
 
     def getDisplayValue(self):
-        '''see :meth:`TaurusBaseComponent.getDisplayValue`'''
+        """see :meth:`TaurusBaseComponent.getDisplayValue`"""
         if self._text is not None:
             return self._text
         if self.widget() is not None:
             return self.widget().__class__.__name__
-        return self._widgetClassName or '---'
+        return self._widgetClassName or "---"
 
     def _updateText(self):
         Qt.QPushButton.setText(self, self.getDisplayValue())
 
     def onClicked(self):
-        '''
+        """
         Slot called when the button is clicked.
         Note that the dialog will only be created once. Subsequent clicks on
-        the button will only raise the existing dialog'''
+        the button will only raise the existing dialog
+        """
         if self.widget() is None:
             self.createWidget()
         self.widget().setModel(self.getModelName())
@@ -233,53 +262,87 @@ class TaurusLauncherButton(Qt.QPushButton, TaurusBaseWidget):
     @classmethod
     def getQtDesignerPluginInfo(cls):
         return {
-            'group': 'Taurus Buttons',
-            'icon': 'designer:pushbutton.png',
-            'module': 'taurus.qt.qtgui.button',
-            'container': False}
+            "group": "Taurus Buttons",
+            "icon": "designer:pushbutton.png",
+            "module": "taurus.qt.qtgui.button",
+            "container": False,
+        }
 
-    ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
-    #                      Qt Properties                        #
-    ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
-    Model = Qt.pyqtProperty("QString", TaurusBaseWidget.getModel,
-                            TaurusBaseWidget.setModel, TaurusBaseWidget.resetModel)
-    UseParentModel = Qt.pyqtProperty("bool", TaurusBaseWidget.getUseParentModel,
-                                     TaurusBaseWidget.setUseParentModel, TaurusBaseWidget.resetUseParentModel)
+    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    #                      Qt Properties
+    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    Model = Qt.pyqtProperty(
+        "QString",
+        TaurusBaseWidget.getModel,
+        TaurusBaseWidget.setModel,
+        TaurusBaseWidget.resetModel,
+    )
+    UseParentModel = Qt.pyqtProperty(
+        "bool",
+        TaurusBaseWidget.getUseParentModel,
+        TaurusBaseWidget.setUseParentModel,
+        TaurusBaseWidget.resetUseParentModel,
+    )
     widgetClassName = Qt.pyqtProperty(
-        "QString", getWidgetClassName, setWidgetClassName, resetWidgetClassName)
+        "QString", getWidgetClassName, setWidgetClassName, resetWidgetClassName
+    )
 
 
 class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
-    '''This class provides a button that executes a tango command on its device.
+    """This class provides a button that executes a tango command on its
+    device.
 
     Code examples::
 
-        # a button that executes the "status" command for the 'a/b/c' device server
-        button =  TaurusCommandButton(command = 'Status', icon='logos:taurus.png')
+        # a button that executes the "status" command for
+        # the 'a/b/c' device server
+        button =  TaurusCommandButton(
+            command = 'Status', icon='logos:taurus.png'
+            )
         button.setModel('a/b/c')
 
-        #  a button that executes the "exec" command for the 'a/b/c' device server with one parameter
-        button =  TaurusCommandButton(command = 'Status', parameters=['2+2'],icon='logos:taurus.png')
+        #  a button that executes the "exec" command for
+        # the 'a/b/c' device server with one parameter
+        button =  TaurusCommandButton(
+            command = 'Status', parameters=['2+2'],icon='logos:taurus.png'
+            )
         button.setModel('a/b/c')
 
     .. seealso:: :class:`TaurusCommandsForm` provides a good example of use of
-                 TaurusCommandButton (including managing the return value) '''
+                 TaurusCommandButton (including managing the return value)
+    """
+
     # TODO: tango-centric
-    commandExecuted = Qt.pyqtSignal(object)
+    commandExecuted = Qt.pyqtSignal(compat.PY_OBJECT)
 
-    def __init__(self, parent=None, designMode=False, command=None,
-                 parameters=None, icon=None, text=None,
-                 timeout=None):
-        '''Constructor
+    def __init__(
+        self,
+        parent=None,
+        designMode=False,
+        command=None,
+        parameters=None,
+        icon=None,
+        text=None,
+        timeout=None,
+    ):
+        """Constructor
 
-        :param parent: (Qt.QWidget or None) parent of this widget
-        :param designMode: (bool) flag for Qt designer
-        :param command: (str) the name of the command to be executed
-        :param parameters: (sequence<str>) the list of parameteres. Default value is None meaning no parameters
-        :param icon: (Qt.QIcon) icon for the button
-        :param text: (str) the button text (if None passed, `command` is used)
-        :param timeout: (float) the command timeout (in seconds)
-        '''
+        :param parent: parent of this widget
+        :type parent: Qt.QWidget or None
+        :param designMode: flag for Qt designer
+        :type designMode: bool
+        :param command: the name of the command to be executed
+        :type command: str
+        :param parameters: the list of parameteres. Default value is None
+            meaning no parameters
+        :type parameters: sequence<str>
+        :param icon: icon for the button
+        :type icon: Qt.QIcon
+        :param text: the button text (if None passed, `command` is used)
+        :type text: str
+        :param timeout: the command timeout (in seconds)
+        :type timeout: float
+        """
         name = self.__class__.__name__
         if command is None:
             command = ""
@@ -299,14 +362,14 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
         self.clicked.connect(self.onClicked)
 
     def getDisplayValue(self):
-        '''see :meth:`TaurusBaseComponent.displayValue`'''
+        """see :meth:`TaurusBaseComponent.displayValue`"""
         if self._customText is not None:
             return self._customText
         if len(self._command) == 0:
-            return '---'
+            return "---"
         modelobj = self.getModelObj()
         if modelobj is None or not hasattr(modelobj, self._command):
-            return '---'
+            return "---"
         return self._command
 
     @ProtectTaurusMessageBox(title="Unexpected error when executing command")
@@ -314,31 +377,38 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
         return self._onClicked()
 
     def _onClicked(self):
-        '''Slot called when the button is clicked. It executes the command with
+        """Slot called when the button is clicked. It executes the command with
         parameters. It may issue a warning if the command is flagged as
-        dangerous. On successful execution, it returns the command result and it
-        emits a "commandExecuted" signal with the result as well.
+        dangerous. On successful execution, it returns the command result and
+        it emits a "commandExecuted" signal with the result as well.
 
         :return: The result of the command. The type depends on the command. It
-                 may be None.
+            may be None.
 
-        .. seealso:: :meth:`setCommand`, :meth:`setParameters`, :meth:`TaurusBaseComponent.isDangerous`
-        '''
+
+        .. seealso:: :meth:`setCommand`, :meth:`setParameters`,
+            :meth:`TaurusBaseComponent.isDangerous`
+        """
 
         self.debug("launch command %s" % str(self._command))
         if len(self._command) == 0:
             return
         modelobj = self.getModelObj()
         if modelobj is None or not hasattr(modelobj, self._command):
-            self.warning('Device %s does not implement command %s' %
-                         (modelobj, self._command))
+            self.warning(
+                "Device %s does not implement command %s"
+                % (modelobj, self._command)
+            )
             return
 
         if self.isDangerous() and not self.getForceDangerousOperations():
-            result = Qt.QMessageBox.question(self, "Potentially dangerous action",
-                                             "%s\nProceed?" % self.getDangerMessage(),
-                                             Qt.QMessageBox.Ok | Qt.QMessageBox.Cancel,
-                                             Qt.QMessageBox.Ok)
+            result = Qt.QMessageBox.question(
+                self,
+                "Potentially dangerous action",
+                "%s\nProceed?" % self.getDangerMessage(),
+                Qt.QMessageBox.Ok | Qt.QMessageBox.Cancel,
+                Qt.QMessageBox.Ok,
+            )
             if result != Qt.QMessageBox.Ok:
                 return
         # After all the checks, we can finally do the action
@@ -346,11 +416,17 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
         try:
             if self._timeout is not None:
                 modelobj.set_timeout_millis(int(self._timeout * 1000))
-            result = modelobj.command_inout(self._command, self._castParameters(
-                self._parameters, self._command, modelobj))
+            result = modelobj.command_inout(
+                self._command,
+                self._castParameters(
+                    self._parameters, self._command, modelobj
+                ),
+            )
         except Exception as e:
-            self.error('Unexpected error when executing command %s of %s: %s' % (
-                self._command, modelobj.getNormalName(), str(e)))
+            self.error(
+                "Unexpected error when executing command %s of %s: %s"
+                % (self._command, modelobj.getNormalName(), str(e))
+            )
             raise
         finally:
             modelobj.set_timeout_millis(orig_timeout)
@@ -359,18 +435,21 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
         return result
 
     def _castParameters(self, parameters=None, command=None, dev=None):
-        '''Internal method used to cast the command paramters to the appropriate
-        type required for the given command
+        """Internal method used to cast the command paramters to the
+        appropriate type required for the given command
 
-        :param parameters: (sequence) a sequence of parameters. If None is
-                           passed, the currently set parameters are used.
-        :param command: (str) the command name. If None is passed, the currently
-                        set command is used.
-        :param dev: (taurus.core.taurusdevice.TaurusDevice) the device on which the command is
-                    executed. If None is passed, the current model is used.
-
-        :return: (sequence or scalar) a sequence of parameters (or a scalar if only one parameter)
-        '''
+        :param parameters: a sequence of parameters. If None is passed, the
+            currently set parameters are used.
+        :type parameters: sequence
+        :param command: the command name. If None is passed, the currently set
+            command is used.
+        :type command: str
+        :param dev: the device on which the command is executed. If None is
+            passed, the current model is used.
+        :type dev: taurus.core.taurusdevice.TaurusDevice
+        :return: a sequence of parameters (or a scalar if only one parameter)
+        :rtype: sequence or scalar
+        """
         import PyTango
 
         if parameters is None:
@@ -384,7 +463,9 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
             param_type = dev.command_query(command).in_type
         except Exception as e:
             self.warning(
-                'Cannot get parameters info for command %s:%s' % (command, str(e)))
+                "Cannot get parameters info for command %s:%s"
+                % (command, str(e))
+            )
             return parameters
         if param_type == PyTango.CmdArgType.DevVoid:
             return None
@@ -392,13 +473,21 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
             cast_type = int
         elif PyTango.is_float_type(param_type, True):
             cast_type = float
-        elif param_type == PyTango.CmdArgType.DevVarStringArray or param_type == PyTango.CmdArgType.DevString:
+        elif (
+            param_type == PyTango.CmdArgType.DevVarStringArray
+            or param_type == PyTango.CmdArgType.DevString
+        ):
             cast_type = str
-        elif param_type == PyTango.CmdArgType.DevVarBooleanArray or param_type == PyTango.CmdArgType.DevBoolean:
+        elif (
+            param_type == PyTango.CmdArgType.DevVarBooleanArray
+            or param_type == PyTango.CmdArgType.DevBoolean
+        ):
             cast_type = bool
         else:
             self.info(
-                'Unsupported parameters type (%s). Casting to "str"' % str(param_type))
+                'Unsupported parameters type (%s). Casting to "str"'
+                % str(param_type)
+            )
             cast_type = str
         if PyTango.is_scalar_type(param_type):
             if parameters:
@@ -409,10 +498,11 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
             return list(map(cast_type, parameters))
 
     def setCommand(self, commandName):
-        '''sets the command to be executed when the button is clicked
+        """sets the command to be executed when the button is clicked
 
-        :param commandName: (str or None) the command name
-        '''
+        :param commandName: the command name
+        :type commandName: str or None
+        """
         if commandName is None:
             self._command = ""
         else:
@@ -420,32 +510,32 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
         self._setText(self.getDisplayValue())
 
     def getCommand(self):
-        '''returns the command name to be executed when the button is clicked
+        """returns the command name to be executed when the button is clicked
 
-        :return: (str or None) the command name
-        '''
+        :return: the command name
+        :rtype: str or None
+        """
         return self._command
 
     def resetCommand(self):
-        '''equivalent to self.setCommand(None)'''
+        """equivalent to self.setCommand(None)"""
         self.setCommand("")
 
     def setParameters(self, parameters):
-        '''
+        """
         Sets the parameters to be used on command execution.
 
-        :param parameters: (sequence) a sequence of parameters. If the
-                           elements of the sequence are not of the right type
-                           required for the parameter, an automatic conversion
-                           will be attempted on execution time. As a special
-                           case, if parameters is a string not starting and
-                           ending in quote characters, it will be splitted on
-                           whitespace to obtain a sequence of parameters. If
-                           it is a string starting and ending with quotes, the
-                           quotes will be removed and the quoted text will not
-                           be splitted.
-        '''
-        if isinstance(parameters, string_types):
+        :param parameters: a sequence of parameters. If the elements of the
+            sequence are not of the right type required for the parameter, an
+            automatic conversion will be attempted on execution time. As a
+            special case, if parameters is a string not starting and ending in
+            quote characters, it will be splitted on whitespace to obtain a
+            sequence of parameters. If it is a string starting and ending with
+            quotes, the quotes will be removed and the quoted text will not be
+            splitted.
+        :type parameters: sequence
+        """
+        if isinstance(parameters, str):
             parameters = str(parameters).strip()
             if parameters[0] in ('"', "'") and parameters[0] == parameters[-1]:
                 parameters = [parameters[1:-1]]
@@ -454,102 +544,122 @@ class TaurusCommandButton(Qt.QPushButton, TaurusBaseWidget):
         self._parameters = parameters
 
     def getParameters(self):
-        '''returns the parameters to be used on command execution
+        """returns the parameters to be used on command execution
 
-        :param parameters: (sequence)
-        '''
+        :param parameters:
+        :type parameters: sequence
+        """
         return self._parameters
 
     def resetParameters(self):
-        '''Equivalent to setParameters([])
-        '''
+        """Equivalent to setParameters([])"""
         self.setParameters([])
 
     def setCustomText(self, customText=None):
-        '''Sets a custom text for the button (by default it is the command name)
+        """Sets a custom text for the button (by default it is the command
+        name)
 
-        :param customText: (str or None) the custom text. If None passed, it
-                           will use the command name
-        '''
+        :param customText: the custom text. If None passed, it will use the
+            command name
+        :type customText: str or None
+        """
         self._customText = customText
         self._setText(self.getDisplayValue())
 
     def getCustomText(self):
-        '''Returns the custom text of the buttom, or None if no custom text is
+        """Returns the custom text of the buttom, or None if no custom text is
         used
-        '''
+        """
         return self._customText
 
     def resetCustomText(self):
-        '''Equivalent to setCustomText(None)'''
+        """Equivalent to setCustomText(None)"""
         self.setCustomText(None)
 
     @Qt.pyqtSlot(float)
     @Qt.pyqtSlot(int)
     def setTimeout(self, timeout):
-        '''Sets the number of seconds to wait for the result of the command.
+        """Sets the number of seconds to wait for the result of the command.
 
         .. seealso:: :meth:`PyTango.DeviceProxy.command_inout`
 
-        :param timeout: (float) the command timeout in seconds
-                        (timeout <0 or timeout=None disables the timeout)
-        '''
+        :param timeout: the command timeout in seconds (timeout <0 or
+            timeout=None disables the timeout)
+        :type timeout: float
+        """
         if timeout < 0:
             timeout = None
         self._timeout = timeout
 
     def getTimeout(self):
-        '''
+        """
         Returns the number of seconds to wait for the result of the command
         (or -1 if timeout is disabled)
-        '''
+        """
         ret = self._timeout
         if ret is None or ret < 0:
             ret = -1
         return ret
 
     def resetTimeout(self):
-        '''Equivalent to setTimeout(None)'''
+        """Equivalent to setTimeout(None)"""
         self.setTimeout(None)
 
     @classmethod
     def getQtDesignerPluginInfo(cls):
         return {
-            'group': 'Taurus Buttons',
-            'icon': 'designer:pushbutton.png',
-            'module': 'taurus.qt.qtgui.button',
-            'container': False}
+            "group": "Taurus Buttons",
+            "icon": "designer:pushbutton.png",
+            "module": "taurus.qt.qtgui.button",
+            "container": False,
+        }
 
-    ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
-    #                      Qt Properties                        #
-    ##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
+    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    #                      Qt Properties
+    # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    Model = Qt.pyqtProperty("QString", TaurusBaseWidget.getModel,
-                            TaurusBaseWidget.setModel, TaurusBaseWidget.resetModel)
+    Model = Qt.pyqtProperty(
+        "QString",
+        TaurusBaseWidget.getModel,
+        TaurusBaseWidget.setModel,
+        TaurusBaseWidget.resetModel,
+    )
 
-    UseParentModel = Qt.pyqtProperty("bool", TaurusBaseWidget.getUseParentModel,
-                                     TaurusBaseWidget.setUseParentModel, TaurusBaseWidget.resetUseParentModel)
+    UseParentModel = Qt.pyqtProperty(
+        "bool",
+        TaurusBaseWidget.getUseParentModel,
+        TaurusBaseWidget.setUseParentModel,
+        TaurusBaseWidget.resetUseParentModel,
+    )
 
     Command = Qt.pyqtProperty("QString", getCommand, setCommand, resetCommand)
 
     Parameters = Qt.pyqtProperty(
-        "QStringList", getParameters, setParameters, resetParameters)
+        "QStringList", getParameters, setParameters, resetParameters
+    )
 
-    DangerMessage = Qt.pyqtProperty("QString", TaurusBaseWidget.getDangerMessage,
-                                    TaurusBaseWidget.setDangerMessage, TaurusBaseWidget.resetDangerMessage)
+    DangerMessage = Qt.pyqtProperty(
+        "QString",
+        TaurusBaseWidget.getDangerMessage,
+        TaurusBaseWidget.setDangerMessage,
+        TaurusBaseWidget.resetDangerMessage,
+    )
 
     CustomText = Qt.pyqtProperty(
-        "QString", getCustomText, setCustomText, resetCustomText)
+        "QString", getCustomText, setCustomText, resetCustomText
+    )
 
     Timeout = Qt.pyqtProperty("double", getTimeout, setTimeout, resetTimeout)
 
 
 class TaurusLockButton(Qt.QPushButton, TaurusBaseWidget):
 
-    _LOCK_MAP = {LockStatus.Unlocked: "extra_icons:lock_unlocked.svg",
-                 LockStatus.Locked: "extra_icons:lock_locked_unpreviledged.svg",
-                 LockStatus.LockedMaster: "extra_icons:lock_locked.svg",
-                 LockStatus.Unknown: "extra_icons:lock_unknown.svg"}
+    _LOCK_MAP = {
+        LockStatus.Unlocked: "extra_icons:lock_unlocked.svg",
+        LockStatus.Locked: "extra_icons:lock_locked_unpreviledged.svg",
+        LockStatus.LockedMaster: "extra_icons:lock_locked.svg",
+        LockStatus.Unknown: "extra_icons:lock_unknown.svg",
+    }
 
     def __init__(self, parent=None, designMode=False):
         self._lock_info = TaurusLockInfo()
@@ -565,10 +675,11 @@ class TaurusLockButton(Qt.QPushButton, TaurusBaseWidget):
     @classmethod
     def getQtDesignerPluginInfo(cls):
         return {
-            'group': 'Taurus Buttons',
-            'icon': 'designer:pushbutton.png',
-            'module': 'taurus.qt.qtgui.button',
-            'container': False}
+            "group": "Taurus Buttons",
+            "icon": "designer:pushbutton.png",
+            "module": "taurus.qt.qtgui.button",
+            "container": False,
+        }
 
     def getModelClass(self):
         return TaurusDevice
@@ -604,22 +715,28 @@ class TaurusLockButton(Qt.QPushButton, TaurusBaseWidget):
     def on_toggle(self, down):
         try:
             self._on_toggle(down)
-        except:
+        except Exception:
             import sys
             from taurus.qt.qtgui.dialog import TaurusMessageBox
+
             msgbox = TaurusMessageBox(*sys.exc_info())
             msgbox.setWindowTitle("Error locking device")
             if self.update_button().status == LockStatus.Locked:
                 msgbox.setText(self._lock_info.status_msg)
             msgbox.exec_()
 
-    model = Qt.pyqtProperty("QString", TaurusBaseWidget.getModel, setModel,
-                            TaurusBaseWidget.resetModel)
+    model = Qt.pyqtProperty(
+        "QString",
+        TaurusBaseWidget.getModel,
+        setModel,
+        TaurusBaseWidget.resetModel,
+    )
 
 
 def lockButtonMain():
     import sys
     import taurus.qt.qtgui.application
+
     Application = taurus.qt.qtgui.application.TaurusApplication
 
     app = Application.instance()
@@ -627,11 +744,17 @@ def lockButtonMain():
 
     if owns_app:
         import taurus.core.util.argparse
+
         parser = taurus.core.util.argparse.get_taurus_parser()
         parser.usage = "%prog [options] <full_attribute_name(s)>"
-        app = Application(sys.argv, cmd_line_parser=parser,
-                          app_name="Taurus lock button demo", app_version="1.0",
-                          org_domain="Taurus", org_name="Tango community")
+        app = Application(
+            sys.argv,
+            cmd_line_parser=parser,
+            app_name="Taurus lock button demo",
+            app_version="1.0",
+            org_domain="Taurus",
+            org_name="Tango community",
+        )
 
     args = app.get_command_line_args()
 
@@ -659,15 +782,23 @@ def commandButtonMain():
     import sys
     from taurus.qt.qtgui.application import TaurusApplication
 
-    app = TaurusApplication()
-    form = TaurusCommandButton(parent=None, designMode=False, command='DevBoolean', parameters=[
-                               123], icon='logos:taurus.png', text='launch: DevBoolean 123')
-    form.setModel('sys/tg_test/1')
+    app = TaurusApplication(cmd_line_parser=None)
+    form = TaurusCommandButton(
+        parent=None,
+        designMode=False,
+        command="DevBoolean",
+        parameters=[123],
+        icon="logos:taurus.png",
+        text="launch: DevBoolean 123",
+    )
+    form.setModel("sys/tg_test/1")
     form.setDangerMessage(
-        'Booo scary command!!\n Maybe you should think twice!')
+        "Booo scary command!!\n Maybe you should think twice!"
+    )
 
     def f(*a):
         print(a)
+
     form.commandExecuted.connect(f)
     form.show()
     sys.exit(app.exec_())
@@ -677,7 +808,7 @@ def launcherButtonMain():
     import sys
     from taurus.qt.qtgui.application import TaurusApplication
 
-    app = TaurusApplication()
+    app = TaurusApplication(cmd_line_parser=None)
 
     # Creating button giving the widget
     # from taurus.qt.qtgui.plot import TaurusPlot
@@ -693,12 +824,13 @@ def launcherButtonMain():
     # Creating button using a derived class with the name widget class
     # hardcoded
     class MyButton(TaurusLauncherButton):
-        _widgetClassName = 'TaurusPlot'
-        _icon = 'logos:taurus.png'
-        _text = 'show'
+        _widgetClassName = "taurus_pyqtgraph:TaurusPlot"
+        _icon = "logos:taurus.png"
+        _text = "show"
+
     form = MyButton()
 
-    form.setModel('sys/tg_test/1/wave')
+    form.setModel("sys/tg_test/1/wave")
     form.show()
     sys.exit(app.exec_())
 
@@ -708,13 +840,13 @@ def main():
 
 
 def demo():
-    '''Lock button'''
+    """Lock button"""
     lock_button = TaurusLockButton()
     lock_button.model = "sys/tg_test/1"
     return lock_button
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # lockButtonMain()
     launcherButtonMain()
     # commandButtonMain()
