@@ -1,32 +1,30 @@
 #!/usr/bin/env python
 
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
-"""This module provides an arrow based widget."""
-
-from builtins import map
-from builtins import range
+"""This module provides an arrow based widget.
+"""
 
 import os
 import math
@@ -36,9 +34,7 @@ from taurus.external.qt import Qt
 from taurus.core.units import Q_
 
 
-__all__ = ["QWheelEdit"]
-
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
 
 class _ArrowButton(Qt.QPushButton):
@@ -55,12 +51,13 @@ class _ArrowButton(Qt.QPushButton):
         pixmap = self.getPixmap()
         self.setIcon(Qt.QIcon(pixmap))
         self.setIconSize(
-            Qt.QSize(_ArrowButton.IconSize, _ArrowButton.IconSize))
+            Qt.QSize(_ArrowButton.IconSize, _ArrowButton.IconSize)
+        )
         self.setFocusPolicy(Qt.Qt.ClickFocus)
         self.setFlat(True)
-        self.setStyleSheet('_ArrowButton { border: 0px; }')
+        self.setStyleSheet("_ArrowButton { border: 0px; }")
         self.setMaximumSize(_ArrowButton.ButtonSize, _ArrowButton.ButtonSize)
-        #self.setMinimumSize(_ArrowButton.ButtonSize, _ArrowButton.ButtonSize)
+        # self.setMinimumSize(_ArrowButton.ButtonSize, _ArrowButton.ButtonSize)
         self._id = id
         self._inc = math.pow(10, id)
 
@@ -98,17 +95,22 @@ class _DownArrowButton(_ArrowButton):
             Qt.QPixmapCache.insert(_DownArrowButton.ArrowPixmapKey, pm)
         return pm
 
+
 class _DigitLabel(Qt.QLabel):
     """A private single digit label to be used by QWheelEdit widget"""
 
-    PixmapKeys = list(map(str, range(10))) + ['blank', 'minus', 'point']
+    PixmapKeys = list(map(str, range(10))) + ["blank", "minus", "point"]
 
     def __init__(self, lbl, parent=None):
         Qt.QLabel.__init__(self, parent)
         self.setAlignment(Qt.Qt.AlignCenter)
         self.setFocusPolicy(Qt.Qt.StrongFocus)
         self.setStyleSheet(
-            """QLabel:focus {background-color: rgb(180,180,255); border-width: 1px; border-style: solid; border-color: rgb(200,200,255);}""")
+            "QLabel:focus {background-color: rgb(180,180,255); "
+            + "border-width: 1px; "
+            + "border-style: solid; "
+            + "border-color: rgb(200,200,255);}"
+        )
         self.resetSkin()
         self.setText(lbl)
         self._upButton = None
@@ -130,13 +132,13 @@ class _DigitLabel(Qt.QLabel):
         Qt.QLabel.keyPressEvent(self, key_event)
 
     def _update_skin_cache(self):
-        skin = os.path.join('digits', self.getSkin())
+        skin = os.path.join("digits", self.getSkin())
 
         for i, d in enumerate(self.PixmapKeys):
             full_name = os.path.join(skin, d)
             pm = Qt.QPixmapCache.find(full_name)
             if pm is None:
-                file_name = '%s.png' % full_name
+                file_name = "%s.png" % full_name
                 pm = Qt.QPixmap(file_name)
                 if pm is None:
                     continue
@@ -152,40 +154,32 @@ class _DigitLabel(Qt.QLabel):
         return self._skin
 
     def resetSkin(self):
-        self.setSkin('Nixie')
+        self.setSkin("Nixie")
 
     def setText(self, t):
         k = t
-        if k == '.':
-            k = 'point'
-        elif k == '-':
-            k = 'minus'
-        elif k is None or k == '+':
-            k = 'blank'
+        if k == ".":
+            k = "point"
+        elif k == "-":
+            k = "minus"
+        elif k is None or k == "+":
+            k = "blank"
 
-        k = os.path.join('digits', self.getSkin(), k)
+        k = os.path.join("digits", self.getSkin(), k)
         pm = Qt.QPixmapCache.find(k)
         if pm is None:
             Qt.QLabel.setText(self, t)
             return
-        Qt.QLabel.setText(self, '')
+        Qt.QLabel.setText(self, "")
         self.setPixmap(pm)
 
-    skin = Qt.pyqtProperty('QString', getSkin, setSkin, resetSkin)
-
-
-class _NumericEditor(Qt.QLineEdit):
-    """A private editor to be used by QWheelEdit widget"""
-
-    def __init__(self, parent=None):
-        Qt.QLineEdit.__init__(self, parent)
-        self.setValidator(Qt.QDoubleValidator(self))
-        self.setFrame(False)
+    skin = Qt.pyqtProperty("QString", getSkin, setSkin, resetSkin)
 
 
 class QWheelEdit(Qt.QFrame):
     """A widget designed to handle numeric scalar values. It allows interaction
-    based on single digit as well as normal value edition."""
+    based on single digit as well as normal value edition.
+    """
 
     numberChanged = Qt.pyqtSignal(float)
     numberEdited = Qt.pyqtSignal(float)
@@ -197,27 +191,34 @@ class QWheelEdit(Qt.QFrame):
     def __init__(self, parent=None):
         """__init__(self, parent = None) -> QWheelEdit
 
-        Constructor
-
-        @param[in] parent (QWidget) the parent widget (optional, default is None
-                          meaning there is no parent
+        :param parent: the parent widget (optional, default is None
+                       meaning there is no parent
         """
         Qt.QFrame.__init__(self, parent)
         Qt.QGridLayout(self)
         self._roundFunc = None
         self._previous_value = 0
         self._value = 0
-        self._value_str = '0'
-        self._minValue = numpy.finfo('d').min  # -inf
-        self._maxValue = numpy.finfo('d').max  # inf
+        self._value_str = "0"
+        self._minValue = numpy.finfo("d").min  # -inf
+        self._maxValue = numpy.finfo("d").max  # inf
         self._editor = None
         self._editing = False
+        self._hideEditWidget = True
         self._showArrowButtons = True
-        self._setDigits(QWheelEdit.DefaultIntDigitCount,
-                        QWheelEdit.DefaultDecDigitCount)
+        self._forwardReturn = False
+        self._validator = Qt.QDoubleValidator(self)
+        self._validator.setNotation(self._validator.StandardNotation)
+        self._setDigits(
+            QWheelEdit.DefaultIntDigitCount, QWheelEdit.DefaultDecDigitCount
+        )
         self._setValue(0)
 
         self._build()
+        self.setDigitCountAction = Qt.QAction("Change digits", self)
+        self.setDigitCountAction.triggered.connect(self._onSetDigitCount)
+        self.addAction(self.setDigitCountAction)
+        self.setContextMenuPolicy(Qt.Qt.ActionsContextMenu)
 
     def _getMinPossibleValue(self):
         """_getMinPossibleValue(self) -> None
@@ -248,36 +249,36 @@ class QWheelEdit(Qt.QFrame):
     def _build(self):
         """_build(self) -> None
 
-        Builds this widget sub-items"""
+        Builds this widget sub-items
+        """
 
-        l = self.layout()
-        l.setSpacing(0)
-        l.setContentsMargins(0, 0, 0, 0)
+        lyt = self.layout()
+        lyt.setSpacing(0)
+        lyt.setContentsMargins(0, 0, 0, 0)
 
         id = self.getIntDigitCount()
-        dd = self.getDecDigitCount()
         digits = self.getDigitCount()
 
         self._upButtons = Qt.QButtonGroup()
         self._downButtons = Qt.QButtonGroup()
         self._digitLabels = []
-        for l in self._digitLabels:
-            l.setAlignment(Qt.AlignCenter)
+        for lyt in self._digitLabels:
+            lyt.setAlignment(Qt.AlignCenter)
 
         showDot = self.getDecDigitCount() > 0
 
-        signLabel = _DigitLabel('+')
+        signLabel = _DigitLabel("+")
         signLabel.setFocusPolicy(Qt.Qt.NoFocus)
         signLabel.setAlignment(Qt.Qt.AlignRight | Qt.Qt.AlignVCenter)
         self._digitLabels.append(signLabel)
-        l.addWidget(signLabel, 1, 0)
-        l.setRowMinimumHeight(1, signLabel.minimumSizeHint().height())
-        l.setColumnMinimumWidth(0, _ArrowButton.ButtonSize)
-        l.setColumnStretch(0, 1)
+        lyt.addWidget(signLabel, 1, 0)
+        lyt.setRowMinimumHeight(1, signLabel.minimumSizeHint().height())
+        lyt.setColumnMinimumWidth(0, _ArrowButton.ButtonSize)
+        lyt.setColumnStretch(0, 1)
 
         for i in range(id):
             col = i + 1
-            d = _DigitLabel('0')
+            d = _DigitLabel("0")
             up = _UpArrowButton(id - i - 1)
             down = _DownArrowButton(id - i - 1)
             d.setButtons(up, down)
@@ -287,22 +288,22 @@ class QWheelEdit(Qt.QFrame):
             self._downButtons.addButton(down, col)
             self._digitLabels.append(d)
             if self.getShowArrowButtons():
-                l.addWidget(up, 0, col)
-                l.addWidget(down, 2, col)
-            l.addWidget(d, 1, col)
+                lyt.addWidget(up, 0, col)
+                lyt.addWidget(down, 2, col)
+            lyt.addWidget(d, 1, col)
 
         if showDot:
-            dotLabel = _DigitLabel('.')
+            dotLabel = _DigitLabel(".")
             dotLabel.setFocusPolicy(Qt.Qt.NoFocus)
             dotLabel.setAlignment(Qt.Qt.AlignCenter)
             self._digitLabels.append(dotLabel)
-            l.addWidget(dotLabel, 1, id + 1)
+            lyt.addWidget(dotLabel, 1, id + 1)
 
         for i in range(id, digits):
             col = i + 1
             if showDot:
                 col += 1
-            d = _DigitLabel('0')
+            d = _DigitLabel("0")
             up = _UpArrowButton(id - i - 1)
             down = _DownArrowButton(id - i - 1)
             d.setButtons(up, down)
@@ -312,29 +313,34 @@ class QWheelEdit(Qt.QFrame):
             self._downButtons.addButton(down, col)
             self._digitLabels.append(d)
             if self.getShowArrowButtons():
-                l.addWidget(up, 0, col)
-                l.addWidget(down, 2, col)
-            l.addWidget(d, 1, col)
+                lyt.addWidget(up, 0, col)
+                lyt.addWidget(down, 2, col)
+            lyt.addWidget(d, 1, col)
 
         self._upButtons.buttonClicked.connect(self.buttonPressed)
         self._downButtons.buttonClicked.connect(self.buttonPressed)
 
-        ed = _NumericEditor(self)
+        ed = Qt.QLineEdit(self)
+        ed.setFrame(False)
         ed.returnPressed.connect(self.editingFinished)
-        ed.editingFinished.connect(ed.hide)
-        rect = Qt.QRect(l.cellRect(1, 0).topLeft(),
-                        l.cellRect(1, l.columnCount() - 1).bottomRight())
+        ed.editingFinished.connect(self.hideEditWidget)
+        rect = Qt.QRect(
+            lyt.cellRect(1, 0).topLeft(),
+            lyt.cellRect(1, lyt.columnCount() - 1).bottomRight(),
+        )
         ed.setGeometry(rect)
         ed.setAlignment(Qt.Qt.AlignRight)
-        ed.validator().setRange(self.getMinValue(), self.getMaxValue(),
-                                self.getDecDigitCount())
+        ed.setValidator(self._validator)
         ed.setVisible(False)
         self._editor = ed
 
+        self._updateValidator()
+
         # set the minimum height for the widget
         # (otherwise the hints seem to be ignored by the layouts)
-        min_height = max(ed.minimumSizeHint().height(),
-                         signLabel.minimumSizeHint().height())
+        min_height = max(
+            ed.minimumSizeHint().height(), signLabel.minimumSizeHint().height()
+        )
         if self.getShowArrowButtons():
             min_height += 2 * _ArrowButton.ButtonSize
         self.setMinimumHeight(min_height)
@@ -344,7 +350,8 @@ class QWheelEdit(Qt.QFrame):
     def _clear(self):
         """_clear(self) -> None
 
-        Clears this widget sub-items"""
+        Clears this widget sub-items
+        """
 
         self._upButtons.buttonClicked.disconnect(self.buttonPressed)
         self._downButtons.buttonClicked.disconnect(self.buttonPressed)
@@ -369,17 +376,6 @@ class QWheelEdit(Qt.QFrame):
         self._editor.destroy()
         self._editor = None
 
-    def _setMinMax(self, min, max):
-        """_setMinMax(self, min, max) -> None
-
-        Sets the minimum and maximum values for this widget
-
-        @param[in] min(float) minimum value
-        @param[in] max(float) maximum value
-        """
-        self._minValue = min
-        self._maxValue = max
-
     def _setDigits(self, int_nb=None, dec_nb=None):
         """_setDigits(self, int_nb=None, dec_nb=None) -> None
 
@@ -393,9 +389,9 @@ class QWheelEdit(Qt.QFrame):
                    None, meaning use the existing number of decimal digits
         """
 
-        if not int_nb is None:
+        if int_nb is not None:
             self._intDigitCount = int_nb
-        if not dec_nb is None:
+        if dec_nb is not None:
             self._decDigitCount = dec_nb
 
         # make sure that the current value can be displayed
@@ -406,9 +402,8 @@ class QWheelEdit(Qt.QFrame):
         total_chars += 1  # for sign
         if self._decDigitCount > 0:
             total_chars += 1  # for dot
-        self._valueFormat = '%%+0%d.%df' % (total_chars, self._decDigitCount)
-        self._setMinMax(self._getMinPossibleValue(),
-                        self._getMaxPossibleValue())
+        self._valueFormat = "%%+0%d.%df" % (total_chars, self._decDigitCount)
+        self._updateValidator()
         # we call setValue to update the self._value_str
         self._setValue(self.getValue())
 
@@ -423,11 +418,11 @@ class QWheelEdit(Qt.QFrame):
         @return (str) a proper string representation of the given value
         """
         if v is None:
-            ret = (self._valueFormat % 0).replace('0', '-')
+            ret = (self._valueFormat % 0).replace("0", "-")
         else:
             ret = self._valueFormat % v
-            if ret.endswith('nan'):
-                ret = ret.replace('0', ' ')
+            if ret.endswith("nan"):
+                ret = ret.replace("0", " ")
         self._value_str = ret
         return ret
 
@@ -442,21 +437,24 @@ class QWheelEdit(Qt.QFrame):
         self._updateValue(False, False)
 
     def _updateValue(self, trigValueChanged=True, trigValueEdited=True):
-        """_updateValue(self, trigValueChanged=True, trigValueEdited=True) -> None
+        """
+        _updateValue(self, trigValueChanged=True, trigValueEdited=True) -> None
 
         Updates this widget displayed value and potentially send signal(s)
 
-        @param[in] trigValueChanged (bool) (optional, default is True) wheather or
-                   not to send signal 'valueChanged(double)'
-        @param[in] trigValueEdited (bool) (optional, default is True) wheather or
-                   not to send signal 'valueEdit(double)'
+        :param trigValueChanged: (optional, default is True) whether or
+            not to send signal 'valueChanged(double)'
+        :type trigValueChanged: bool
+        :param trigValueEdited: (optional, default is True) whether or
+            not to send signal 'valueEdit(double)'
+        :type trigValueEdited: bool
         """
         v, v_str = self.getValue(), self.getValueStr()
 
         if len(v_str) > len(self._digitLabels):
             # do auto adjust
-            if '.' in v_str:
-                dc = list(map(len, v_str.split('.')))
+            if "." in v_str:
+                dc = list(map(len, v_str.split(".")))
             else:
                 dc = len(v_str), 0
             self._setDigits(*dc)
@@ -476,8 +474,8 @@ class QWheelEdit(Qt.QFrame):
     def setRoundFunc(self, roundFunc):
         """setRoundFunc(self, roundFunc) -> None
 
-        Sets the rounding function to use when calling _setValue(). This allows you to
-        filter invalid user input
+        Sets the rounding function to use when calling _setValue(). This allows
+        you to filter invalid user input
 
         @param[in] roundFunc (callable) the rounding function to use
         """
@@ -498,13 +496,28 @@ class QWheelEdit(Qt.QFrame):
         Sets value of this widget. If the given value exceeds any limit, the
         value is NOT set.
         """
+        if v is None:
+            return
         if self._roundFunc:
             v = self._roundFunc(v)
-        if v > self._maxValue or v < self._minValue:
+        if v > self._validator.top() or v < self._validator.bottom():
+            Qt.QMessageBox.warning(
+                self,
+                "Invalid Value",
+                "'{}' is out of the allowed range ({}, {})".format(
+                    v,
+                    self._validator.bottom(),
+                    self._validator.top(),
+                ),
+            )
             return
         self._previous_value = self._value
         self._value = v
-        self._buildValueStr(v)
+
+        str_value = self._buildValueStr(v)
+        ed = self.getEditWidget()
+        if ed is not None:
+            ed.setText(str_value)
 
     def setWarning(self, msg):
         """setWarning(self, msg) -> None
@@ -515,7 +528,10 @@ class QWheelEdit(Qt.QFrame):
         @param[in] msg (str) the message to be displayed as tooltip
         """
         self.setStyleSheet(
-            'QWheelEdit {border: 1px solid; border-radius: 4px; border-color: violet}')
+            "QWheelEdit {border: 1px solid; "
+            + "border-radius: 4px; "
+            + "border-color: violet}"
+        )
         self.setToolTip(msg)
 
     def clearWarning(self):
@@ -524,8 +540,11 @@ class QWheelEdit(Qt.QFrame):
         Clears the warning style. If not in warning mode, nothing is done.
         """
         self.setStyleSheet(
-            'QWheelEdit {border: 1px solid; border-radius: 4px; border-color: rgba(0,0,0,0)}')
-        self.setToolTip('')
+            "QWheelEdit {border: 1px solid; "
+            + "border-radius: 4px; "
+            + "border-color: rgba(0,0,0,0)}"
+        )
+        self.setToolTip("")
 
     def buttonPressed(self, b):
         """buttonPressed(self, b) -> None
@@ -534,8 +553,32 @@ class QWheelEdit(Qt.QFrame):
 
         @param[in] b (_ArrowButton) the button which was pressed
         """
-        self._setValue(self.getValue() + b._inc)
-        self._updateValue()
+        if self._editing:
+            self.hideEditWidget()
+        else:
+            self._setValue(self.getValue() + b._inc)
+            self._updateValue()
+
+    def _onSetDigitCount(self):
+        text, ok = Qt.QInputDialog.getText(
+            self,
+            "Change digits",
+            "Enter digits as <int_nb>.<dec_nb>",
+            text="{:d}.{:d}".format(
+                self.getIntDigitCount(), self.getDecDigitCount()
+            ),
+        )
+        if ok:
+            try:
+                dc = list(map(int, text.split(".")))
+                self.setDigitCount(*dc)
+            except Exception as e:
+                Qt.QMessageBox.warning(
+                    self,
+                    "Invalid digit count specification",
+                    'Invalid specification: "{}"\nReason:{}'.format(text, e),
+                )
+                self._onSetDigitCount()
 
     def setDigitCount(self, int_nb, dec_nb):
         """setDigitCount(self, int_nb, dec_nb) -> None
@@ -579,7 +622,8 @@ class QWheelEdit(Qt.QFrame):
     def resetIntDigitCount(self):
         """resetIntDigitCount(self) -> None
 
-        Resets the number of integer digits this widget displays to DefaultIntDigitCount
+        Resets the number of integer digits this widget displays to
+        DefaultIntDigitCount
         """
         self.setIntDigitCount(QWheelEdit.DefaultIntDigitCount)
 
@@ -606,7 +650,8 @@ class QWheelEdit(Qt.QFrame):
     def resetDecDigitCount(self):
         """resetDecDigitCount(self) -> None
 
-        Resets the number of decimal digits this widget displays to DefaultDecDigitCount
+        Resets the number of decimal digits this widget displays to
+        DefaultDecDigitCount
         """
         self.setDecDigitCount(QWheelEdit.DefaultDecDigitCount)
 
@@ -665,17 +710,19 @@ class QWheelEdit(Qt.QFrame):
         @param[in] v (float) the new minimum allowed value
         """
         self._minValue = v
-        w = self.getEditWidget()
-        if not w is None:
-            w.validator().setRange(self._minValue, self._maxValue, self._decDigitCount)
+        self._updateValidator()
+
+    def _updateValidator(self):
+        min_ = max(self._minValue, self._getMinPossibleValue())
+        max_ = min(self._maxValue, self._getMaxPossibleValue())
+        self._validator.setRange(min_, max_, self._decDigitCount)
 
     def resetMinValue(self):
         """resetMinValue(self) -> None
 
-        Resets the minimum allowed value to the minimum possible according to
-        the current total number of digits
+        Resets the minimum allowed value to -inf
         """
-        self.setMinValue(self._getMinPossibleValue())
+        self.setMinValue(numpy.finfo("d").min)
 
     def getMaxValue(self):
         """getMaxValue(self) -> float
@@ -694,17 +741,14 @@ class QWheelEdit(Qt.QFrame):
         @param[in] v (float) the new maximum allowed value
         """
         self._maxValue = v
-        w = self.getEditWidget()
-        if not w is None:
-            w.validator().setRange(self._minValue, self._maxValue, self._decDigitCount)
+        self._updateValidator()
 
     def resetMaxValue(self):
         """resetMaxValue(self) -> None
 
-        Resets the maximum allowed value to the maximum possible according to
-        the current total number of digits
+        Resets the maximum allowed value to +inf
         """
-        self.setMaxValue(self._getMaxPossibleValue())
+        self.setMaxValue(numpy.finfo("d").max)
 
     def getAutoRepeat(self):
         return self._upButtons.buttons()[0].autoRepeat()
@@ -760,16 +804,18 @@ class QWheelEdit(Qt.QFrame):
 
         Forces the edition widget to be displayed
         """
-        ed, l = self.getEditWidget(), self.layout()
-        rect = Qt.QRect(l.cellRect(1, 0).topLeft(), l.cellRect(1,
-                                                               l.columnCount() - 1).bottomRight())
+        ed, lyt = self.getEditWidget(), self.layout()
+        rect = Qt.QRect(
+            lyt.cellRect(1, 0).topLeft(),
+            lyt.cellRect(1, lyt.columnCount() - 1).bottomRight(),
+        )
         ed.setGeometry(rect)
         ed.setAlignment(Qt.Qt.AlignRight)
-        ed.setMaxLength(self.getDigitCount() + 2)
         ed.setText(self.getValueStr())
         ed.selectAll()
         ed.setFocus()
         ed.setVisible(True)
+        self._editing = True
 
     def hideEditWidget(self):
         """hideEditWidget(self) -> None
@@ -778,12 +824,13 @@ class QWheelEdit(Qt.QFrame):
         """
         ed = self.getEditWidget()
         ed.setVisible(False)
+        self._editing = False
         self.setFocus()
 
     def wheelEvent(self, evt):
         numDegrees = evt.delta() // 8
         numSteps = numDegrees // 15
-        #w = Qt.QApplication.focusWidget()
+        # w = Qt.QApplication.focusWidget()
         w = self.focusWidget()
         if not isinstance(w, _DigitLabel):
             return Qt.QFrame.wheelEvent(self, evt)
@@ -803,7 +850,6 @@ class QWheelEdit(Qt.QFrame):
         widget when this happens
         """
         self.showEditWidget()
-        self._editing = True
 
     def keyPressEvent(self, key_event):
         """keyPressEvent(self, key_event) -> None
@@ -815,20 +861,16 @@ class QWheelEdit(Qt.QFrame):
         if k == Qt.Qt.Key_F2:
             if self._editing:
                 self.hideEditWidget()
-                self._editing = False
             else:
                 self.showEditWidget()
-                self._editing = True
             return
         elif k == Qt.Qt.Key_Escape:
             if self._editing:
                 self.hideEditWidget()
-                self._editing = False
                 return
         elif k in (Qt.Qt.Key_Return, Qt.Qt.Key_Enter):
             if self._editing:
                 self.hideEditWidget()
-                self._editing = False
             else:
                 self.returnPressed.emit()
 
@@ -845,40 +887,105 @@ class QWheelEdit(Qt.QFrame):
     def resetShowArrowButtons(self):
         self.setShowArrowButtons(True)
 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    def getHideEditWidget(self):
+        """getHideEditWidget(self) -> bool
+
+        Gets the info if edition widget should be hidden when 'focusOut' event
+        occurs.
+
+        @return (bool)
+        """
+        return self._hideEditWidget
+
+    def setHideEditWidget(self, focus_out=True):
+        """setFocusOut(self, focus_out=True) -> None
+
+        Sets if edition widget should be hidden when 'focusOut' event occurs.
+        If set to False, edition widget is hidden only when 'F2', 'Esc',
+        'Enter' and arrow button are pressed. Default set to True.
+
+        @param[in] focus_out (bool) whether or not to hide edition widget
+        after 'focusOut' event.
+        """
+        if focus_out and not self._hideEditWidget:
+            ed = self.getEditWidget()
+            ed.editingFinished.connect(self.hideEditWidget)
+            self._hideEditWidget = True
+        elif not focus_out and self._hideEditWidget:
+            ed = self.getEditWidget()
+            ed.editingFinished.disconnect(self.hideEditWidget)
+            self._hideEditWidget = False
+
+    def isReturnForwarded(self):
+        """isReturnForwarded(self) -> bool
+
+        Gets the info if returnPressed is forwarded.
+
+        @return (bool)
+        """
+        return self._forwardReturn
+
+    def setReturnForwarded(self, forward_rtn=False):
+        """setReturnForwarded(self, forward_rtn=False) -> None
+
+        Sets forwarding of returnPressed. If set to True, returnPressed from
+        edition widget emits returnPressed of 'QWheelEdit' widget.
+
+        @param[in] forward_rtn (bool) whether or not to forward returnPressed
+        signal
+        """
+        if forward_rtn and not self._forwardReturn:
+            ed = self.getEditWidget()
+            ed.returnPressed.connect(self.returnPressed)
+            self._forwardReturn = True
+
+        elif not forward_rtn and self._forwardReturn:
+            ed = self.getEditWidget()
+            ed.returnPressed.disconnect(self.returnPressed)
+            self._forwardReturn = False
+
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
     # QT properties
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
-    showArrowButtons = Qt.pyqtProperty("bool", getShowArrowButtons,
-                                       setShowArrowButtons,
-                                       resetShowArrowButtons)
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
+    showArrowButtons = Qt.pyqtProperty(
+        "bool", getShowArrowButtons, setShowArrowButtons, resetShowArrowButtons
+    )
 
-    integerDigits = Qt.pyqtProperty("int", getIntDigitCount,
-                                    setIntDigitCount, resetIntDigitCount)
+    integerDigits = Qt.pyqtProperty(
+        "int", getIntDigitCount, setIntDigitCount, resetIntDigitCount
+    )
 
-    decimalDigits = Qt.pyqtProperty("int", getDecDigitCount,
-                                    setDecDigitCount, resetDecDigitCount)
+    decimalDigits = Qt.pyqtProperty(
+        "int", getDecDigitCount, setDecDigitCount, resetDecDigitCount
+    )
 
-    value = Qt.pyqtProperty("double", getValue,
-                            setValue, resetValue)
+    value = Qt.pyqtProperty("double", getValue, setValue, resetValue)
 
-    minValue = Qt.pyqtProperty("double", getMinValue,
-                               setMinValue, resetMinValue)
+    minValue = Qt.pyqtProperty(
+        "double", getMinValue, setMinValue, resetMinValue
+    )
 
-    maxValue = Qt.pyqtProperty("double", getMaxValue,
-                               setMaxValue, resetMaxValue)
+    maxValue = Qt.pyqtProperty(
+        "double", getMaxValue, setMaxValue, resetMaxValue
+    )
 
-    autoRepeat = Qt.pyqtProperty("bool", getAutoRepeat,
-                                 setAutoRepeat, resetAutoRepeat)
+    autoRepeat = Qt.pyqtProperty(
+        "bool", getAutoRepeat, setAutoRepeat, resetAutoRepeat
+    )
 
-    autoRepeatDelay = Qt.pyqtProperty("int", getAutoRepeatDelay,
-                                      setAutoRepeatDelay)
+    autoRepeatDelay = Qt.pyqtProperty(
+        "int", getAutoRepeatDelay, setAutoRepeatDelay
+    )
 
-    autoRepeatInterval = Qt.pyqtProperty("int", getAutoRepeatInterval,
-                                         setAutoRepeatInterval)
+    autoRepeatInterval = Qt.pyqtProperty(
+        "int", getAutoRepeatInterval, setAutoRepeatInterval
+    )
 
 
 def main():
-    import taurus.qt.qtgui.icon  # otherwise the arrows don't show in the demo
+    # unused import to initialize the icons
+    import taurus.qt.qtgui.icon  # noqa: F401
+
     global arrowWidget
 
     def resetAll():
@@ -889,13 +996,14 @@ def main():
         arrowWidget.resetValue()
 
     def setNAN():
-        arrowWidget.setValue(float('nan'))
+        arrowWidget.setValue(float("nan"))
 
     def setNone():
         arrowWidget.setValue(None)
+
     a = Qt.QApplication([])
     panel = Qt.QWidget()
-    l = Qt.QFormLayout(panel)
+    lyt = Qt.QFormLayout(panel)
     button_layout = Qt.QVBoxLayout()
     arrowWidget = QWheelEdit(panel)
     isb, dsb = Qt.QSpinBox(panel), Qt.QSpinBox(panel)
@@ -904,22 +1012,25 @@ def main():
     resetbutton.setDefault(True)
     nanbutton = Qt.QPushButton("Set NAN", panel)
     nonebutton = Qt.QPushButton("Set None", panel)
+    hideEditCB = Qt.QCheckBox()
+    hideEditCB.setChecked(True)
     showarrowbutton = Qt.QCheckBox("", panel)
 
-    l.addRow("Value", arrowWidget)
-    l.addRow("Integer digits:", isb)
-    l.addRow("Decimal digits:", dsb)
-    l.addRow("Minimum value:", minv)
-    l.addRow("Maximum value:", maxv)
-    l.addRow("Show arrows:", showarrowbutton)
-    l.addRow(button_layout)
+    lyt.addRow("Value", arrowWidget)
+    lyt.addRow("Integer digits:", isb)
+    lyt.addRow("Decimal digits:", dsb)
+    lyt.addRow("Minimum value:", minv)
+    lyt.addRow("Maximum value:", maxv)
+    lyt.addRow("Show arrows:", showarrowbutton)
+    lyt.addRow("hideEditCB", hideEditCB)
+    lyt.addRow(button_layout)
     button_layout.addWidget(nanbutton)
     button_layout.addWidget(nonebutton)
     button_layout.addWidget(resetbutton)
     isb.setValue(arrowWidget.getIntDigitCount())
     dsb.setValue(arrowWidget.getDecDigitCount())
-    minv.setRange(numpy.finfo('d').min, numpy.finfo('d').max)
-    maxv.setRange(numpy.finfo('d').min, numpy.finfo('d').max)
+    minv.setRange(numpy.finfo("d").min, numpy.finfo("d").max)
+    maxv.setRange(numpy.finfo("d").min, numpy.finfo("d").max)
     minv.setValue(arrowWidget.getMinValue())
     maxv.setValue(arrowWidget.getMaxValue())
     showarrowbutton.setChecked(arrowWidget.getShowArrowButtons())
@@ -929,9 +1040,11 @@ def main():
     showarrowbutton.stateChanged.connect(arrowWidget.setShowArrowButtons)
     nanbutton.clicked.connect(setNAN)
     nonebutton.clicked.connect(setNone)
+    hideEditCB.toggled.connect(arrowWidget.setHideEditWidget)
     resetbutton.clicked.connect(resetAll)
     panel.setVisible(True)
     a.exec_()
 
+
 if __name__ == "__main__":
     main()
