@@ -1,45 +1,42 @@
 #!/usr/bin/env python
 
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
 """This module provides base widget that displays a Qt view widget envolved
-by a toolbar and a status bar (optional)"""
+by a toolbar and a status bar (optional)
+"""
 
-__all__ = ["QBaseModelWidget", "TaurusBaseModelWidget",
-           "BaseToolBar", "FilterToolBar", "EditorToolBar", "SelectionToolBar",
-           "RefreshToolBar", "PerspectiveToolBar"]
 
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
-from taurus.external.qt import Qt
+from taurus.external.qt import Qt, compat
 
 from taurus.qt.qtgui.util import ActionFactory
 from taurus.qt.qtgui.base import TaurusBaseWidget
 
 
 class BaseToolBar(Qt.QToolBar):
-
     def __init__(self, name=None, view=None, parent=None, designMode=False):
         if name is None:
             name = "Base toolbar"
@@ -56,27 +53,35 @@ class BaseToolBar(Qt.QToolBar):
 class FilterToolBar(BaseToolBar):
     """Internal widget providing quick filter to be placed in a _QToolArea"""
 
-    filterEdited = Qt.pyqtSignal('const QString &')
-    filterChanged = Qt.pyqtSignal('const QString &')
+    filterEdited = Qt.pyqtSignal("const QString &")
+    filterChanged = Qt.pyqtSignal("const QString &")
     clearFilterTriggered = Qt.pyqtSignal()
 
     def __init__(self, view=None, parent=None, designMode=False):
-        BaseToolBar.__init__(self, name="Taurus filter toolbar", view=view,
-                             parent=parent, designMode=designMode)
+        BaseToolBar.__init__(
+            self,
+            name="Taurus filter toolbar",
+            view=view,
+            parent=parent,
+            designMode=designMode,
+        )
         filterLineEdit = self._filterLineEdit = Qt.QLineEdit(self)
-        filterLineEdit.setSizePolicy(Qt.QSizePolicy(Qt.QSizePolicy.Preferred,
-                                                    Qt.QSizePolicy.Preferred))
+        filterLineEdit.setSizePolicy(
+            Qt.QSizePolicy(Qt.QSizePolicy.Preferred, Qt.QSizePolicy.Preferred)
+        )
         filterLineEdit.setToolTip("Quick filter")
         filterLineEdit.textChanged.connect(self.onFilterChanged)
         filterLineEdit.textEdited.connect(self.onFilterEdited)
         self.addWidget(filterLineEdit)
 
         af = ActionFactory()
-        self._clearFilterAction = af.createAction(self, "Clear",
-                                                  icon=Qt.QIcon.fromTheme(
-                                                      "edit-clear"),
-                                                  tip="Clears the filter",
-                                                  triggered=self.onClearFilter)
+        self._clearFilterAction = af.createAction(
+            self,
+            "Clear",
+            icon=Qt.QIcon.fromTheme("edit-clear"),
+            tip="Clears the filter",
+            triggered=self.onClearFilter,
+        )
         self.addAction(self._clearFilterAction)
 
     def getFilterLineEdit(self):
@@ -100,54 +105,75 @@ class FilterToolBar(BaseToolBar):
 
 class EditorToolBar(BaseToolBar):
     """Internal widget to be placed in a _QToolArea providing buttons for
-    moving, adding and removing items from a view based widget"""
+    moving, adding and removing items from a view based widget
+    """
 
     addTriggered = Qt.pyqtSignal()
-    removeTriggered  = Qt.pyqtSignal()
+    removeTriggered = Qt.pyqtSignal()
     moveTopTriggered = Qt.pyqtSignal()
     moveDownTriggered = Qt.pyqtSignal()
     moveUpTriggered = Qt.pyqtSignal()
     moveBottomTriggered = Qt.pyqtSignal()
 
     def __init__(self, view=None, parent=None, designMode=False):
-        BaseToolBar.__init__(self, name="Taurus editor toolbar", view=view,
-                             parent=parent, designMode=designMode)
+        BaseToolBar.__init__(
+            self,
+            name="Taurus editor toolbar",
+            view=view,
+            parent=parent,
+            designMode=designMode,
+        )
 
         af = ActionFactory()
-        self._addAction = af.createAction(self, "New item",
-                                          icon=Qt.QIcon.fromTheme("list-add"),
-                                          tip="Add new item",
-                                          triggered=self.onAdd)
-        self._removeAction = af.createAction(self, "Remove item",
-                                             icon=Qt.QIcon.fromTheme(
-                                                 "list-remove"),
-                                             tip="Remove item",
-                                             triggered=self.onRemove)
-        self._moveTopAction = af.createAction(self, "To top",
-                                              icon=Qt.QIcon.fromTheme("go-top"),
-                                              tip="Move selected item to top",
-                                              triggered=self.onMoveTop)
-        self._moveUpAction = af.createAction(self, "Move up",
-                                             icon=Qt.QIcon.fromTheme("go-up"),
-                                             tip="Move selected item up one level",
-                                             triggered=self.onMoveUp)
-        self._moveDownAction = af.createAction(self, "Move down",
-                                               icon=Qt.QIcon.fromTheme(
-                                                   "go-down"),
-                                               tip="Move selected item down one level",
-                                               triggered=self.onMoveDown)
-        self._moveBottomAction = af.createAction(self, "To bottom",
-                                                 icon=Qt.QIcon.fromTheme(
-                                                     "go-bottom"),
-                                                 tip="Move selected item to bottom",
-                                                 triggered=self.onMoveBottom)
+        self._addAction = af.createAction(
+            self,
+            "New item",
+            icon=Qt.QIcon.fromTheme("list-add"),
+            tip="Add new item",
+            triggered=self.onAdd,
+        )
+        self._removeAction = af.createAction(
+            self,
+            "Remove item",
+            icon=Qt.QIcon.fromTheme("list-remove"),
+            tip="Remove item",
+            triggered=self.onRemove,
+        )
+        self._moveTopAction = af.createAction(
+            self,
+            "To top",
+            icon=Qt.QIcon.fromTheme("go-top"),
+            tip="Move selected item to top",
+            triggered=self.onMoveTop,
+        )
+        self._moveUpAction = af.createAction(
+            self,
+            "Move up",
+            icon=Qt.QIcon.fromTheme("go-up"),
+            tip="Move selected item up one level",
+            triggered=self.onMoveUp,
+        )
+        self._moveDownAction = af.createAction(
+            self,
+            "Move down",
+            icon=Qt.QIcon.fromTheme("go-down"),
+            tip="Move selected item down one level",
+            triggered=self.onMoveDown,
+        )
+        self._moveBottomAction = af.createAction(
+            self,
+            "To bottom",
+            icon=Qt.QIcon.fromTheme("go-bottom"),
+            tip="Move selected item to bottom",
+            triggered=self.onMoveBottom,
+        )
         self.addAction(self._addAction)
         self.addAction(self._removeAction)
         self.addAction(self._moveTopAction)
         self.addAction(self._moveUpAction)
         self.addAction(self._moveDownAction)
         self.addAction(self._moveBottomAction)
-        #self.setStyleSheet("QWidget {background : red; }")
+        # self.setStyleSheet("QWidget {background : red; }")
 
     def onAdd(self):
         self.addTriggered.emit()
@@ -174,20 +200,29 @@ class SelectionToolBar(BaseToolBar):
     clearSelectionTriggered = Qt.pyqtSignal()
 
     def __init__(self, view=None, parent=None, designMode=False):
-        BaseToolBar.__init__(self, name="Taurus selection toolbar", view=view,
-                             parent=parent, designMode=designMode)
+        BaseToolBar.__init__(
+            self,
+            name="Taurus selection toolbar",
+            view=view,
+            parent=parent,
+            designMode=designMode,
+        )
 
         af = ActionFactory()
-        self._selectAllAction = af.createAction(self, "Select All",
-                                                icon=Qt.QIcon.fromTheme(
-                                                    "edit-select-all"),
-                                                tip="Select all items",
-                                                triggered=self.onSelectAll)
-        self._clearSelectionAction = af.createAction(self, "Clear selection",
-                                                     icon=Qt.QIcon.fromTheme(
-                                                         "edit-clear"),
-                                                     tip="Clears current selection",
-                                                     triggered=self.onclearSelection)
+        self._selectAllAction = af.createAction(
+            self,
+            "Select All",
+            icon=Qt.QIcon.fromTheme("edit-select-all"),
+            tip="Select all items",
+            triggered=self.onSelectAll,
+        )
+        self._clearSelectionAction = af.createAction(
+            self,
+            "Clear selection",
+            icon=Qt.QIcon.fromTheme("edit-clear"),
+            tip="Clears current selection",
+            triggered=self.onclearSelection,
+        )
 
         self.addAction(self._selectAllAction)
         self.addAction(self._clearSelectionAction)
@@ -204,15 +239,22 @@ class RefreshToolBar(BaseToolBar):
     refreshTriggered = Qt.pyqtSignal()
 
     def __init__(self, view=None, parent=None, designMode=False):
-        BaseToolBar.__init__(self, name="Taurus refresh toolbar", view=view,
-                             parent=parent, designMode=designMode)
+        BaseToolBar.__init__(
+            self,
+            name="Taurus refresh toolbar",
+            view=view,
+            parent=parent,
+            designMode=designMode,
+        )
 
         af = ActionFactory()
-        self._refreshAction = af.createAction(self, "Refresh",
-                                              icon=Qt.QIcon.fromTheme(
-                                                  "view-refresh"),
-                                              tip="Refresh view",
-                                              triggered=self.onRefresh)
+        self._refreshAction = af.createAction(
+            self,
+            "Refresh",
+            icon=Qt.QIcon.fromTheme("view-refresh"),
+            tip="Refresh view",
+            triggered=self.onRefresh,
+        )
         self.addAction(self._refreshAction)
 
     def onRefresh(self):
@@ -221,11 +263,16 @@ class RefreshToolBar(BaseToolBar):
 
 class PerspectiveToolBar(BaseToolBar):
 
-    perspectiveChanged = Qt.pyqtSignal(str)
+    perspectiveChanged = Qt.pyqtSignal(compat.PY_OBJECT)
 
     def __init__(self, perspective, view=None, parent=None, designMode=False):
-        BaseToolBar.__init__(self, name="Taurus refresh toolbar", view=view,
-                             parent=parent, designMode=designMode)
+        BaseToolBar.__init__(
+            self,
+            name="Taurus refresh toolbar",
+            view=view,
+            parent=parent,
+            designMode=designMode,
+        )
         self._perspective = perspective
         view = self.viewWidget()
         b = self._perspective_button = Qt.QToolButton(self)
@@ -240,8 +287,13 @@ class PerspectiveToolBar(BaseToolBar):
             label = persp_data["label"]
             icon = Qt.QIcon.fromTheme(persp_data["icon"])
             tip = persp_data["tooltip"]
-            action = af.createAction(self, label, icon=icon, tip=tip,
-                                     triggered=self.onSwitchPerspective)
+            action = af.createAction(
+                self,
+                label,
+                icon=icon,
+                tip=tip,
+                triggered=self.onSwitchPerspective,
+            )
             action.perspective = persp
             menu.addAction(action)
             if persp == perspective:
@@ -252,7 +304,8 @@ class PerspectiveToolBar(BaseToolBar):
     def switchPerspectiveButton(self):
         """Returns the QToolButton that handles the switch perspective.
 
-        :return: (PyQt4.QtGui.QToolButton) the switch perspective tool button
+        :return: the switch perspective tool button
+        :rtype: PyQt5.Qt.QToolButton
         """
         return self._perspective_button
 
@@ -270,19 +323,27 @@ class QBaseModelWidget(Qt.QMainWindow):
     """A pure Qt widget designed to display a Qt view widget (QTreeView for
     example), envolved by optional toolbar and statusbar.
     The Qt model associated with the internal Qt view widget should be a
-    :class:`taurus.qt.qtcore.model.TaurusBaseModel`"""
+    :class:`taurus.qt.qtcore.model.TaurusBaseModel`
+    """
 
     KnownPerspectives = {}
     DftPerspective = None
 
-    itemClicked = Qt.pyqtSignal(object, int)
-    itemDoubleClicked = Qt.pyqtSignal(object, int)
+    itemClicked = Qt.pyqtSignal(compat.PY_OBJECT, int)
+    itemDoubleClicked = Qt.pyqtSignal(compat.PY_OBJECT, int)
     itemSelectionChanged = Qt.pyqtSignal()
-    currentItemChanged = Qt.pyqtSignal(object, object)
+    currentItemChanged = Qt.pyqtSignal(compat.PY_OBJECT, compat.PY_OBJECT)
 
-    def __init__(self, parent=None, designMode=False, with_filter_widget=True,
-                 with_selection_widget=True, with_refresh_widget=True,
-                 perspective=None, proxy=None):
+    def __init__(
+        self,
+        parent=None,
+        designMode=False,
+        with_filter_widget=True,
+        with_selection_widget=True,
+        with_refresh_widget=True,
+        perspective=None,
+        proxy=None,
+    ):
         Qt.QMainWindow.__init__(self, parent)
         self.setWindowFlags(Qt.Qt.Widget)
         self._baseQModel = None
@@ -330,7 +391,8 @@ class QBaseModelWidget(Qt.QMainWindow):
 
         if len(self.KnownPerspectives) > 1:
             p_bar = self._perspectiveBar = PerspectiveToolBar(
-                perspective, view=self, parent=self)
+                perspective, view=self, parent=self
+            )
             p_bar.perspectiveChanged.connect(self.onSwitchPerspective)
             self.addToolBar(p_bar)
         else:
@@ -349,7 +411,8 @@ class QBaseModelWidget(Qt.QMainWindow):
         tb = []  # tb = self._toolArea = QToolArea(self)
         if self._with_filter_widget:
             f_bar = self._filterBar = self._with_filter_widget(
-                view=self, parent=self)
+                view=self, parent=self
+            )
             f_bar.filterChanged.connect(self.onFilterChanged)
             tb.append(f_bar)
         else:
@@ -357,7 +420,8 @@ class QBaseModelWidget(Qt.QMainWindow):
 
         if self._with_selection_widget:
             s_bar = self._selectionBar = self._with_selection_widget(
-                view=self, parent=self)
+                view=self, parent=self
+            )
             s_bar.selectAllTriggered.connect(self.onSelectAll)
             s_bar.clearSelectionTriggered.connect(self.onClearSelection)
             tb.append(s_bar)
@@ -366,7 +430,8 @@ class QBaseModelWidget(Qt.QMainWindow):
 
         if self._with_refresh_widget:
             r_bar = self._refreshBar = self._with_refresh_widget(
-                view=self, parent=self)
+                view=self, parent=self
+            )
             r_bar.refreshTriggered.connect(self.onRefreshModel)
             tb.append(r_bar)
         else:
@@ -398,14 +463,16 @@ class QBaseModelWidget(Qt.QMainWindow):
         view.clearSelection()
 
     def _onClicked(self, index):
-        '''Emits an "itemClicked" signal with with the clicked item and column
-        as arguments'''
+        """Emits an "itemClicked" signal with with the clicked item and column
+        as arguments
+        """
         item = self._mapToSource(index).internalPointer()
         self.itemClicked.emit(item, index.column())
 
     def _onDoubleClicked(self, index):
-        '''Emits an "itemDoubleClicked" signal with the clicked item and column
-        as arguments'''
+        """Emits an "itemDoubleClicked" signal with the clicked item and column
+        as arguments
+        """
         item = self._mapToSource(index).internalPointer()
         self.itemDoubleClicked.emit(item, index.column())
 
@@ -438,20 +505,22 @@ class QBaseModelWidget(Qt.QMainWindow):
 
         view = self.viewWidget()
         old_selection_model = view.selectionModel()
-        CC = 'currentChanged(const QModelIndex &,const QModelIndex &)'
-        SC = 'selectionChanged(QItemSelection &, QItemSelection &)'
         if old_selection_model is not None:
             old_selection_model.currentChanged.disconnect(
-                                  self.viewCurrentIndexChanged)
+                self.viewCurrentIndexChanged
+            )
             old_selection_model.selectionChanged.disconnect(
-                                  self.viewSelectionChanged)
+                self.viewSelectionChanged
+            )
         view.setModel(qmodel)
         new_selection_model = view.selectionModel()
         if new_selection_model is not None:
             new_selection_model.currentChanged.connect(
-                               self.viewCurrentIndexChanged)
+                self.viewCurrentIndexChanged
+            )
             new_selection_model.selectionChanged.connect(
-                               self.viewSelectionChanged)
+                self.viewSelectionChanged
+            )
         view.setCurrentIndex(view.rootIndex())
         self._updateToolBar()
 
@@ -474,8 +543,9 @@ class QBaseModelWidget(Qt.QMainWindow):
             previousTaurusTreeItem = base_previous.internalPointer()
         else:
             previousTaurusTreeItem = None
-        self.currentItemChanged.emit(currentTaurusTreeItem,
-                  previousTaurusTreeItem)
+        self.currentItemChanged.emit(
+            currentTaurusTreeItem, previousTaurusTreeItem
+        )
 
     def _updateToolBar(self, current=None, previous=None):
         pass
@@ -483,17 +553,21 @@ class QBaseModelWidget(Qt.QMainWindow):
     def selectedItems(self):
         """Returns a list of all selected non-hidden items
 
-        :return: (list<TaurusTreeItem>)
+        :return:
+        :rtype: list<TaurusTreeItem>
         """
         view = self.viewWidget()
-        return [self._mapToSource(index).internalPointer() for index in view.selectedIndexes()]
+        return [
+            self._mapToSource(index).internalPointer()
+            for index in view.selectedIndexes()
+        ]
 
     def onFilterChanged(self, filter):
         if not self.usesProxyQModel():
             return
         proxy_model = self.getQModel()
-        if len(filter) > 0 and filter[0] != '^':
-            filter = '^' + filter
+        if len(filter) > 0 and filter[0] != "^":
+            filter = "^" + filter
         proxy_model.setFilterRegExp(filter)
         # proxy_model.setFilterFixedString(filter)
         # proxy_model.setFilterWildcard(filter)
@@ -502,9 +576,9 @@ class QBaseModelWidget(Qt.QMainWindow):
     def refresh(self):
         self.getQModel().refresh()
 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
     # Perspective handling
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
 
     def perspective(self):
         return self._perspectiveBar.perspective()
@@ -518,7 +592,7 @@ class QBaseModelWidget(Qt.QMainWindow):
             self.getQModel().setSelectables(old_qmodel.selectables())
 
         # set the taurus model (if any) to the qmodel
-        if hasattr(self, 'getModelObj'):
+        if hasattr(self, "getModelObj"):
             taurusModel = self.getModelObj()
             if taurusModel is not None:
                 self.getQModel().setDataSource(taurusModel)
@@ -526,8 +600,10 @@ class QBaseModelWidget(Qt.QMainWindow):
     def _setPerspective(self, perspective):
         qmodel_classes = self.KnownPerspectives[perspective]["model"]
         # reversed
-        qmodel_class, qmodel_proxy_classes = qmodel_classes[
-            -1], qmodel_classes[-2::-1]
+        qmodel_class, qmodel_proxy_classes = (
+            qmodel_classes[-1],
+            qmodel_classes[-2::-1],
+        )
         qmodel = qmodel_class(parent=self)
         qmodel_source = qmodel
         if self._proxyModel is None:  # applies the chain of proxies
@@ -540,9 +616,9 @@ class QBaseModelWidget(Qt.QMainWindow):
             qmodel_source = self._proxyModel
         self.setQModel(qmodel_source)
 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
     # QMainWindow overwriting
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
 
     def addToolBar(self, toolbar):
         Qt.QMainWindow.addToolBar(self, toolbar)
@@ -561,15 +637,16 @@ class QBaseModelWidget(Qt.QMainWindow):
 class TaurusBaseModelWidget(TaurusBaseWidget):
     """A class:`taurus.qt.qtgui.base.TaurusBaseWidget` that connects to a
     taurus model. It must be used together with
-    class:`~taurus.qt.qtgui.base.QBaseModelWidget`"""
+    class:`~taurus.qt.qtgui.base.QBaseModelWidget`
+    """
 
     def __init__(self, designMode=False):  # , perspective=None, proxy=None):
         name = self.__class__.__name__
         self.call__init__(TaurusBaseWidget, name, designMode=designMode)
 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
     # TaurusBaseWidget overwriting
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
 
     def setModel(self, m):
         TaurusBaseWidget.setModel(self, m)
@@ -580,9 +657,9 @@ class TaurusBaseModelWidget(TaurusBaseWidget):
             return
         model.setDataSource(modelObj)
 
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
     # QT property definition
-    #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
+    # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~
 
     #: This property holds the unique URI string representing the model name
     #: with which this widget will get its data from. The convention used for
@@ -595,5 +672,9 @@ class TaurusBaseModelWidget(TaurusBaseWidget):
     #:     * :meth:`TaurusBaseWidget.resetModel`
     #:
     #: .. seealso:: :ref:`model-concept`
-    model = Qt.pyqtProperty("QString", TaurusBaseWidget.getModel, setModel,
-                            TaurusBaseWidget.resetModel)
+    model = Qt.pyqtProperty(
+        "QString",
+        TaurusBaseWidget.getModel,
+        setModel,
+        TaurusBaseWidget.resetModel,
+    )
