@@ -1,62 +1,60 @@
 #!/usr/bin/env python
 
-#############################################################################
-##
+# ###########################################################################
+#
 # This file is part of Taurus
-##
+#
 # http://taurus-scada.org
-##
+#
 # Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-##
+#
 # Taurus is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-##
+#
 # Taurus is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-##
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
-##
-#############################################################################
+#
+# ###########################################################################
 
-"""This module provides Qt table widgets which display logging messages from the
-python :mod:`logging` module"""
-
-from __future__ import absolute_import
+"""This module provides Qt table widgets which display logging messages from
+the python :mod:`logging` module """
 
 from operator import attrgetter
-from builtins import range
 
 import logging
 import logging.handlers
 import datetime
 import threading
 import socket
+import click
 
 import taurus
 from taurus.core.util.log import Logger
-from taurus.core.util.remotelogmonitor import LogRecordStreamHandler, \
-    LogRecordSocketReceiver
+from taurus.core.util.remotelogmonitor import (
+    LogRecordStreamHandler,
+    LogRecordSocketReceiver,
+)
 from taurus.core.util.decorator.memoize import memoized
 
 from taurus.external.qt import Qt
 from taurus.qt.qtgui.model import FilterToolBar
 from taurus.qt.qtgui.util import ActionFactory
+import taurus.cli.common
 
 from .qtable import QBaseTableWidget
 
 
-__all__ = ["QLoggingTableModel", "QLoggingTable", "QLoggingWidget",
-           "QRemoteLoggingTableModel"]
-
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
 LEVEL, TIME, MSG, NAME, ORIGIN = list(range(5))
-HORIZ_HEADER = 'Level', 'Time', 'Message', 'By', 'Origin'
+HORIZ_HEADER = "Level", "Time", "Message", "By", "Origin"
 
 __LEVEL_BRUSH = {
     taurus.Trace: (Qt.Qt.lightGray, Qt.Qt.black),
@@ -90,20 +88,20 @@ gethostname = memoized(socket.gethostname)
 
 
 def _get_record_origin(rec):
-    host = getattr(rec, 'hostName', "?" + gethostname() + "?")
-    procName = getattr(rec, 'processName', "?process?")
-    procID = getattr(rec, 'process', "?PID?")
-    threadName = getattr(rec, 'threadName', "?thread?")
-    threadID = getattr(rec, 'thread', "?threadID?")
+    host = getattr(rec, "hostName", "?" + gethostname() + "?")
+    procName = getattr(rec, "processName", "?process?")
+    procID = getattr(rec, "process", "?PID?")
+    threadName = getattr(rec, "threadName", "?thread?")
+    threadID = getattr(rec, "thread", "?threadID?")
     return host, procName, procID, threadName, threadID
 
 
 def _get_record_trace(rec):
-    pathname = getattr(rec, 'pathname', '')
-    filename = getattr(rec, 'filename', '')
-    modulename = getattr(rec, 'module', '')
-    funcname = getattr(rec, 'funcName', '')
-    lineno = getattr(rec, 'lineno', '')
+    pathname = getattr(rec, "pathname", "")
+    filename = getattr(rec, "filename", "")
+    modulename = getattr(rec, "module", "")
+    funcname = getattr(rec, "funcName", "")
+    lineno = getattr(rec, "lineno", "")
     return pathname, filename, modulename, funcname, lineno
 
 
@@ -116,11 +114,19 @@ def _get_record_origin_tooltip(rec):
     host, procName, procID, threadName, threadID = _get_record_origin(rec)
     pathname, filename, modulename, funcname, lineno = _get_record_trace(rec)
     timestamp = str(datetime.datetime.fromtimestamp(rec.created))
-    bgcolor, fgcolor = list(map(Qt.QBrush.color, getBrushForLevel(rec.levelno)))
+    bgcolor, fgcolor = list(
+        map(Qt.QBrush.color, getBrushForLevel(rec.levelno))
+    )
     bgcolor = "#%02x%02x%02x" % (
-        bgcolor.red(), bgcolor.green(), bgcolor.blue())
+        bgcolor.red(),
+        bgcolor.green(),
+        bgcolor.blue(),
+    )
     fgcolor = "#%02x%02x%02x" % (
-        fgcolor.red(), fgcolor.green(), fgcolor.blue())
+        fgcolor.red(),
+        fgcolor.green(),
+        fgcolor.blue(),
+    )
 
     return """<html><font face="monospace" size="1">
 <table border="0" cellpadding="0" cellspacing="0">
@@ -133,42 +139,62 @@ def _get_record_origin_tooltip(rec):
 <tr><td>Thread:</td><td>{threadname}({threadID})</td></tr>
 <tr><td>From:</td><td>File pathname({filename}), line {lineno}, in {funcname}</td></tr>
 </table></font></html>
-""".format(level=rec.levelname, level_fgcolor=fgcolor, level_bgcolor=bgcolor,
-           timestamp=timestamp, message=rec.getMessage(),
-           name=rec.name, host=host, procname=procName, procID=procID,
-           threadname=threadName, threadID=threadID,
-           pathname=pathname, filename=filename, funcname=funcname,
-           lineno=lineno)
+""".format(  # noqa
+        level=rec.levelname,
+        level_fgcolor=fgcolor,
+        level_bgcolor=bgcolor,
+        timestamp=timestamp,
+        message=rec.getMessage(),
+        name=rec.name,
+        host=host,
+        procname=procName,
+        procID=procID,
+        threadname=threadName,
+        threadID=threadID,
+        pathname=pathname,
+        filename=filename,
+        funcname=funcname,
+        lineno=lineno,
+    )
 
 
 class QLoggingTableModel(Qt.QAbstractTableModel, logging.Handler):
 
     DftFont = Qt.QFont("Mono", 8)
-    DftColSize = Qt.QSize(80, 20), Qt.QSize(200, 20), \
-        Qt.QSize(300, 20), Qt.QSize(180, 20), Qt.QSize(240, 20),
+    DftColSize = (
+        Qt.QSize(80, 20),
+        Qt.QSize(200, 20),
+        Qt.QSize(300, 20),
+        Qt.QSize(180, 20),
+        Qt.QSize(240, 20),
+    )
 
     def __init__(self, parent=None, capacity=500000, freq=0.25):
-        super(Qt.QAbstractTableModel, self).__init__()
+        Qt.QAbstractTableModel.__init__(self, parent=parent)
         logging.Handler.__init__(self)
         self._capacity = capacity
         self._records = []
         self._accumulated_records = []
         Logger.addRootLogHandler(self)
-        self.startTimer(freq * 1000)
+        self.startTimer(int(freq * 1000))
 
     # ---------------------------------
     # Qt.QAbstractTableModel overwrite
     # ---------------------------------
 
     def sort(self, column, order=Qt.Qt.AscendingOrder):
-        column2key_map = {LEVEL: attrgetter('levelno'),
-                          TIME: attrgetter('created'),
-                          MSG: attrgetter('msg'),
-                          NAME: attrgetter('name'),
-                          ORIGIN: attrgetter('process', 'thread', 'name'),
+        column2key_map = {
+            LEVEL: attrgetter("levelno"),
+            TIME: attrgetter("created"),
+            MSG: attrgetter("msg"),
+            NAME: attrgetter("name"),
+            ORIGIN: attrgetter("process", "thread", "name"),
         }
-        self._records = sorted(self._records, key=column2key_map[column],
-                               reverse=order == Qt.Qt.DescendingOrder)
+        self._records = sorted(
+            self._records,
+            key=column2key_map[column],
+            reverse=order == Qt.Qt.DescendingOrder,
+        )
 
     def rowCount(self, index=Qt.QModelIndex()):
         return len(self._records)
@@ -242,8 +268,10 @@ class QLoggingTableModel(Qt.QAbstractTableModel, logging.Handler):
             elif section == NAME:
                 return "object who recorded the log"
             elif section == ORIGIN:
-                return ("the host, process and thread where the"
-                        + " log was executed from")
+                return (
+                    "the host, process and thread where the"
+                    + " log was executed from"
+                )
         if role != Qt.Qt.DisplayRole:
             return None
         if orientation == Qt.Qt.Horizontal:
@@ -303,26 +331,30 @@ class QLoggingTableModel(Qt.QAbstractTableModel, logging.Handler):
 
 
 class _LogRecordStreamHandler(LogRecordStreamHandler):
-
     def handleLogRecord(self, record):
-        self.server.data.get('model').emit(record)
+        self.server.data.get("model").emit(record)
 
 
 class QRemoteLoggingTableModel(QLoggingTableModel):
     """A remote Qt table that displays the taurus logging messages"""
 
-    def connect_logging(self, host='localhost',
-                        port=logging.handlers.DEFAULT_TCP_LOGGING_PORT,
-                        handler=_LogRecordStreamHandler):
-        self.log_receiver = LogRecordSocketReceiver(host=host, port=port,
-                                                    handler=handler, model=self)
+    def connect_logging(
+        self,
+        host="localhost",
+        port=logging.handlers.DEFAULT_TCP_LOGGING_PORT,
+        handler=_LogRecordStreamHandler,
+    ):
+        self.log_receiver = LogRecordSocketReceiver(
+            host=host, port=port, handler=handler, model=self
+        )
         self.log_thread = threading.Thread(
-            target=self.log_receiver.serve_until_stopped)
+            target=self.log_receiver.serve_until_stopped
+        )
         self.log_thread.daemon = False
         self.log_thread.start()
 
     def disconnect_logging(self):
-        if not hasattr(self, 'log_receiver') or self.log_receiver is None:
+        if not hasattr(self, "log_receiver") or self.log_receiver is None:
             return
         self.log_receiver.stop()
         self.log_thread.join()
@@ -336,7 +368,8 @@ class QLoggingTable(Qt.QTableView):
 
     def rowsInserted(self, index, start, end):
         """Overwrite of slot rows inserted to do proper resize and scroll to
-        bottom if desired"""
+        bottom if desired
+        """
         Qt.QTableView.rowsInserted(self, index, start, end)
         for i in range(start, end + 1):
             self.resizeRowToContents(i)
@@ -362,8 +395,9 @@ class LoggingToolBar(FilterToolBar):
     scrollLockToggled = Qt.pyqtSignal(bool)
 
     def __init__(self, view=None, parent=None, designMode=False):
-        FilterToolBar.__init__(self, view=view, parent=parent,
-                               designMode=designMode)
+        FilterToolBar.__init__(
+            self, view=view, parent=parent, designMode=designMode
+        )
         self.getFilterLineEdit().setToolTip("Quick filter by log name")
 
         self._logLevelComboBox = logLevelComboBox = Qt.QComboBox()
@@ -378,11 +412,13 @@ class LoggingToolBar(FilterToolBar):
         self.addSeparator()
 
         af = ActionFactory()
-        self._scrollLockAction = af.createAction(self, "Refresh",
-                                                 icon=Qt.QIcon.fromTheme(
-                                                     "system-lock-screen"),
-                                                 tip="Scroll lock",
-                                                 toggled=self.onToggleScrollLock)
+        self._scrollLockAction = af.createAction(
+            self,
+            "Refresh",
+            icon=Qt.QIcon.fromTheme("system-lock-screen"),
+            tip="Scroll lock",
+            toggled=self.onToggleScrollLock,
+        )
 
         self.addAction(self._scrollLockAction)
 
@@ -402,8 +438,8 @@ class LoggingToolBar(FilterToolBar):
     def setLogLevel(self, level):
         combo = self.getLogLevelComboBox()
         for i in range(combo.count()):
-            l = combo.itemData(i)
-            if l == level:
+            level = combo.itemData(i)
+            if level == level:
                 combo.setCurrentIndex(i)
 
 
@@ -444,37 +480,57 @@ class QLoggingFilterProxyModel(Qt.QSortFilterProxyModel):
         return False
 
 
-_W = "Warning: Switching log perspective will erase previous log messages " \
-     "from current perspective!"
+_W = (
+    "Warning: Switching log perspective will erase previous log messages "
+    "from current perspective!"
+)
 
 
 class QLoggingWidget(QBaseTableWidget):
 
     KnownPerspectives = {
-        'Standard': {
+        "Standard": {
             "label": "Local",
             "icon": "computer",
             "tooltip": "Local logging.\n" + _W,
-            "model": [QLoggingFilterProxyModel, QLoggingTableModel, ],
+            "model": [
+                QLoggingFilterProxyModel,
+                QLoggingTableModel,
+            ],
         },
-        'Remote': {
+        "Remote": {
             "label": "Remote",
             "icon": "network-server",
             "tooltip": "Monitor remote logs.\n" + _W,
-            "model": [QLoggingFilterProxyModel, QRemoteLoggingTableModel, ],
+            "model": [
+                QLoggingFilterProxyModel,
+                QRemoteLoggingTableModel,
+            ],
         },
     }
 
-    DftPerspective = 'Standard'
+    DftPerspective = "Standard"
 
-    def __init__(self, parent=None, designMode=False,
-                 with_filter_widget=LoggingToolBar,
-                 with_selection_widget=True, with_refresh_widget=True,
-                 perspective=None, proxy=None):
-        QBaseTableWidget.__init__(self, parent=parent, designMode=designMode,
-                                  with_filter_widget=with_filter_widget,
-                                  with_selection_widget=False, with_refresh_widget=False,
-                                  perspective=perspective, proxy=proxy)
+    def __init__(
+        self,
+        parent=None,
+        designMode=False,
+        with_filter_widget=LoggingToolBar,
+        with_selection_widget=True,
+        with_refresh_widget=True,
+        perspective=None,
+        proxy=None,
+    ):
+        QBaseTableWidget.__init__(
+            self,
+            parent=parent,
+            designMode=designMode,
+            with_filter_widget=with_filter_widget,
+            with_selection_widget=False,
+            with_refresh_widget=False,
+            perspective=perspective,
+            proxy=proxy,
+        )
 
     def createViewWidget(self, klass=None):
         if klass is None:
@@ -482,10 +538,7 @@ class QLoggingWidget(QBaseTableWidget):
         view = QBaseTableWidget.createViewWidget(self, klass=klass)
         hh = view.horizontalHeader()
         if hh.length() > 0:
-            try:
-                hh.setSectionResizeMode(MSG, Qt.QHeaderView.Stretch)
-            except AttributeError:  # PyQt4
-                hh.setResizeMode(MSG, Qt.QHeaderView.Stretch)
+            hh.setSectionResizeMode(MSG, Qt.QHeaderView.Stretch)
         view.setShowGrid(False)
         view.sortByColumn(TIME, Qt.Qt.AscendingOrder)
         return view
@@ -510,25 +563,34 @@ class QLoggingWidget(QBaseTableWidget):
     def onSwitchPerspective(self, perspective):
         self.stop_logging()
         if perspective == "Remote":
-            if hasattr(self, 'hostName') and hasattr(self, 'port'):
+            if hasattr(self, "hostName") and hasattr(self, "port"):
                 host, port = self.hostName, self.port
             else:
                 isValid = False
-                dft = "%s:%d" % (socket.gethostname(),
-                                 logging.handlers.DEFAULT_TCP_LOGGING_PORT)
+                dft = "%s:%d" % (
+                    socket.gethostname(),
+                    logging.handlers.DEFAULT_TCP_LOGGING_PORT,
+                )
                 while not isValid:
-                    txt, res = Qt.QInputDialog.getText(self,
-                                                       "Please input remote logging host and port",
-                                                       "Location (<host>:<port>):", Qt.QLineEdit.Normal, dft)
+                    txt, res = Qt.QInputDialog.getText(
+                        self,
+                        "Please input remote logging host and port",
+                        "Location (<host>:<port>):",
+                        Qt.QLineEdit.Normal,
+                        dft,
+                    )
                     if not res:
                         return
                     try:
                         host, port = str(txt).split(":", 1)
                         port = int(port)
                         isValid = True
-                    except:
-                        Qt.QMessageBox.information(self, "Invalid name",
-                                                   "Please type a valid <host>:<port>")
+                    except Exception:
+                        Qt.QMessageBox.information(
+                            self,
+                            "Invalid name",
+                            "Please type a valid <host>:<port>",
+                        )
             ret = QBaseTableWidget.onSwitchPerspective(self, perspective)
             qmodel = self.getQModel()
             qmodel.connect_logging(host=host, port=port)
@@ -542,16 +604,17 @@ class QLoggingWidget(QBaseTableWidget):
 
     def stop_logging(self):
         model = self.getBaseQModel()
-        if hasattr(model, 'disconnect_logging'):
+        if hasattr(model, "disconnect_logging"):
             model.disconnect_logging()
 
     @classmethod
     def getQtDesignerPluginInfo(cls):
         return {
-            'module': 'taurus.qt.qtgui.table',
-            'group': 'Taurus Views',
-            'icon': 'designer:table.png',
-            'container': False}
+            "module": "taurus.qt.qtgui.table",
+            "group": "Taurus Views",
+            "icon": "designer:table.png",
+            "container": False,
+        }
 
 
 def fill_log():
@@ -573,14 +636,19 @@ def fill_log():
 
 def main():
     import taurus.qt.qtgui.application
+
     Application = taurus.qt.qtgui.application.TaurusApplication
 
     app = Application.instance()
     owns_app = app is None
 
     if owns_app:
-        app = Application(app_name="Logging demo", app_version="1.0",
-                          org_domain="Taurus", org_name="Taurus community")
+        app = Application(
+            app_name="Logging demo",
+            app_version="1.0",
+            org_domain="Taurus",
+            org_name="Taurus community",
+        )
 
     taurus.setLogLevel(taurus.Trace)
     taurus.disableLogOutput()
@@ -597,5 +665,49 @@ def main():
     app.exec_()
     w.stop_logging()
 
-if __name__ == '__main__':
+
+@click.command("qlogmon")
+@click.option(
+    "--port",
+    "port",
+    type=int,
+    default=logging.handlers.DEFAULT_TCP_LOGGING_PORT,
+    show_default=True,
+    help="Port where log server is running",
+)
+@click.option(
+    "--log-name",
+    "log_name",
+    default=None,
+    help="Filter specific log object",
+)
+@taurus.cli.common.log_level
+def qlogmon_cmd(port, log_name, log_level):
+    """Show the Taurus Remote Log Monitor"""
+    import taurus
+
+    host = socket.gethostname()
+    level = getattr(taurus, log_level.capitalize(), taurus.Trace)
+
+    from taurus.qt.qtgui.application import TaurusApplication
+
+    app = TaurusApplication(
+        cmd_line_parser=None, app_name="Taurus remote logger"
+    )
+    w = QLoggingWidget(perspective="Remote")
+    w.setMinimumSize(1024, 600)
+
+    filterbar = w.getFilterBar()
+    filterbar.setLogLevel(level)
+    if log_name is not None:
+        filterbar.setFilterText(log_name)
+    w.getPerspectiveBar().setEnabled(False)
+    w.getQModel().connect_logging(host, port)
+    w.show()
+    app.exec_()
+    w.getQModel().disconnect_logging()
+
+
+if __name__ == "__main__":
     main()
+    # qlogmon_cmd
